@@ -2,11 +2,14 @@
 
 #include "mpi.h"
 extern int __NUMNODES, __MYPROCID;
-#if HAVE_STDLIB_H
-#include <stdlib.h>
-#endif
 #include "mpptest.h"
 #include "getopts.h"
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
 
 /* 
     This file contains routines to generate output from the mpptest programs
@@ -20,7 +23,7 @@ extern int __NUMNODES, __MYPROCID;
    -wy i n    windows in y, my # and total #
    -lastwindow generate the wait/new page.
  */
-typedef enum { GRF_X, GRF_EPS, GRF_PS } OutputForm;
+typedef enum { GRF_X, GRF_EPS, GRF_PS, GRF_GIF } OutputForm;
 
 struct _GraphData {
     FILE *fp, *fpdata;
@@ -35,6 +38,7 @@ struct _GraphData {
     void (*dataoutgop)( GraphData, int, double, double, double, double, 
 			double );
     void (*drawgop)( GraphData, int, int, double, double, int, int *);
+    void (*endgraph)( GraphData );
     /* Information about the graph */
     int wxi, wxn, wyi, wyn, is_lastwindow;
     int givedy;
@@ -45,6 +49,30 @@ struct _GraphData {
     OutputForm output_type;
     };
 
+/* Forward refs */
+void HeaderCIt( GraphData ctx, char *protocol_name, char *title_string, 
+		char *units );
+void HeaderForGopCIt( GraphData ctx, char *test_name, char *title_string, 
+		      char *units );
+void DrawCIt( GraphData ctx, int first, int last, double s, double r );
+void DrawGopCIt( GraphData ctx, int first, int last, double s, double r, 
+		 int nsizes, int *sizelist );
+void EndPageCIt( GraphData ctx );
+
+void HeaderGnuplot( GraphData ctx, char *protocol_name, 
+		    char *title_string, char *units );
+void HeaderForGopGnuplot( GraphData ctx, char *protocol_name, 
+			  char *title_string, char *units );
+void DrawGnuplot( GraphData ctx, int first, int last, double s, double r );
+void DrawGopGnuplot( GraphData ctx, int first, int last, double s, 
+		     double r, int nsizes, int *sizelist );
+void EndPageGnuplot( GraphData ctx );
+
+void ChangeToRate( GraphData, int );
+
+void EndGraphCIt( GraphData );
+void EndGraphGnuplot( GraphData );
+
 void PrintGraphHelp( void )
 {
 fprintf( stderr, "\n\
@@ -71,13 +99,16 @@ void HeaderCIt( GraphData ctx, char *protocol_name, char *title_string,
     char archname[20], hostname[256], date[30], *p;
     int dummy;
 
+    if (!ctx) return;
+
     fprintf( ctx->fp, "set default\nset font variable\n" );
     fprintf( ctx->fp, "set curve window y 0.15 0.90\n" );
     if (ctx->wxn > 1 || ctx->wyn > 1) 
 	fprintf( ctx->fp, "set window x %d %d y %d %d\n", 
 		 ctx->wxi, ctx->wxn, ctx->wyi, ctx->wyn );
-    if (ctx->givedy) 
+    if (ctx->givedy) {
 	/*fprintf( ctx->fp, "set order d d d x y d d d\n" )*/;
+    }
     else {
 	if (ctx->do_rate) 
 	    fputs( "set order d d d x d y\n", ctx->fp );
@@ -129,6 +160,8 @@ void HeaderForGopCIt( GraphData ctx, char *test_name, char *title_string,
     char archname[20], hostname[256], date[30], *p;
     int  dummy;
 
+    if (!ctx) return;
+
     fprintf( ctx->fp, "set default\nset font variable\n" );
     fprintf( ctx->fp, "set curve window y 0.15 0.90\n" );
     if (ctx->wxn > 1 || ctx->wyn > 1) 
@@ -165,33 +198,53 @@ void HeaderForGopCIt( GraphData ctx, char *test_name, char *title_string,
     fflush( ctx->fp );
 }
 
+/* Time in usec */
 void DataoutGraph( GraphData ctx, int proc1, int proc2, int distance, 
 		   int len, double t, double mean_time, double rate,
 		   double tmean, double tmax )
 {
+    if (!ctx) return;
+
     if(ctx->givedy) 
 	fprintf( ctx->fpdata, "%d\t%d\t%d\t%d\t%f\t%.2f\t%f\t%f\n",
 		 proc1, proc2, distance, len, tmean * 1.0e6, rate, 
 		 mean_time*1.0e6, tmax * 1.0e6 );
-    else
-	fprintf( ctx->fpdata, "%d\t%d\t%d\t%d\t%f\t%.2f\n",
-		 proc1, proc2, distance, len, mean_time*1.0e6, rate );
+    else {
+	/* Update to use e3 or e6 for rate */
+	fprintf( ctx->fpdata, "%d\t%d\t%d\t%d\t%f\t",
+		 proc1, proc2, distance, len, mean_time*1.0e6 );
+	if (rate > 1.0e6) {
+	    fprintf( ctx->fpdata, "%.3fe+6\n", rate * 1.0e-6 );
+	}
+	else if (rate > 1.0e3) {
+	    fprintf( ctx->fpdata, "%.3fe+3\n", rate * 1.0e-3 );
+	}
+	else {
+	    fprintf( ctx->fpdata, "%.2f\n", rate );
+	}
+    }
 }
 
 void DataoutGraphForGop( GraphData ctx, int len, double t, double mean_time, 
 			 double rate, double tmean, double tmax )
 {
+    if (!ctx) return;
+
     fprintf( ctx->fpdata, "%f ", mean_time*1.0e6 );
     fflush( ctx->fpdata );
 }
 
 void DataendForGop( GraphData ctx )
 {
+    if (!ctx) return;
+
     fprintf( ctx->fpdata, "\n" );
 }
 
 void DatabeginForGop( GraphData ctx, int np )
 {
+    if (!ctx) return;
+
     fprintf( ctx->fpdata, "%d ", np );
 }
 
@@ -201,6 +254,9 @@ void RateoutputGraph( GraphData ctx, double sumlen, double sumtime,
 {
     double  s, r;
     double  variance = 0.0;
+
+    if (!ctx) return;
+
     PIComputeRate( sumlen, sumtime, sumlentime, sumlen2, ntest, &s, &r );
     s = s * 0.5;
     r = r * 0.5;
@@ -233,6 +289,8 @@ void RateoutputGraph( GraphData ctx, double sumlen, double sumtime,
 
 void DrawCIt( GraphData ctx, int first, int last, double s, double r )
 {
+    if (!ctx) return;
+
 /* Convert to one-way performance */
     if (ctx->givedy) {
 	fprintf( ctx->fp, "set order d d d x y d d d\n" );
@@ -266,6 +324,9 @@ void DrawGopCIt( GraphData ctx, int first, int last, double s, double r,
 		 int nsizes, int *sizelist )
 {
     int i, j;
+
+    if (!ctx) return;
+
 /* Do this in reverse order to help keep the scales correct */
     fprintf( ctx->fp, "set limits ymin 0\n" );
     for (i=nsizes-1; i>=0; i--) {
@@ -284,6 +345,8 @@ void DrawGopCIt( GraphData ctx, int first, int last, double s, double r,
  */
 void ChangeToRate( GraphData ctx, int n_particip )
 {
+    if (!ctx) return;
+
     fprintf( ctx->fp, "set order d d d x d d y\njoin\n" );
 }
 
@@ -292,6 +355,8 @@ void ChangeToRate( GraphData ctx, int n_particip )
  */
 void EndPageCIt( GraphData ctx )
 {
+    if (!ctx) return;
+
     if (ctx->is_lastwindow)
 	fprintf( ctx->fp, "wait\nnew page\n" );
 }
@@ -305,6 +370,8 @@ void HeaderGnuplot( GraphData ctx, char *protocol_name,
     char archname[20], hostname[256], date[30], *p;
     int  dummy;
 
+    if (!ctx) return;
+
     switch (ctx->output_type) {
     case GRF_EPS:
 	fprintf( ctx->fp, "set terminal postscript eps\n" );
@@ -312,6 +379,9 @@ void HeaderGnuplot( GraphData ctx, char *protocol_name,
     case GRF_PS:
 	fprintf( ctx->fp, "set terminal postscript\n" );
 	break;
+    case GRF_GIF:
+	fprintf( ctx->fp, "set terminal gif\n" );
+	break;
     case GRF_X:
 	/* Default behavior */
 	break;
@@ -347,6 +417,8 @@ void HeaderForGopGnuplot( GraphData ctx, char *protocol_name,
     char archname[20], hostname[256], date[30], *p;
     int  dummy;
 
+    if (!ctx) return;
+
     fprintf( ctx->fp, "set xlabel \"Processes\"\n" );
     fprintf( ctx->fp, "set ylabel \"time (us)\"\n" );
 
@@ -374,9 +446,13 @@ void HeaderForGopGnuplot( GraphData ctx, char *protocol_name,
 
 void DrawGnuplot( GraphData ctx, int first, int last, double s, double r )
 {
-    if (ctx->givedy)
-	fprintf( ctx->fp, "plot '%s' using 4:5:7:8 notitle with errorbars,\\\n", 
+    if (!ctx) return;
+
+    if (ctx->givedy) {
+	fprintf( ctx->fp, 
+		 "plot '%s' using 4:5:7:8 notitle with errorbars", 
 		 ctx->fname2 );
+    }
     else {
 	fprintf( ctx->fp, "plot '%s' using 4:5 notitle with ", ctx->fname2 );
 
@@ -402,6 +478,8 @@ void DrawGopGnuplot( GraphData ctx, int first, int last, double s,
 {
     int i;
 
+    if (!ctx) return;
+
     fprintf( ctx->fp, "plot " );
     for (i=0; i<nsizes; i++) {
 #ifdef GNUVERSION_HAS_BOXES
@@ -420,6 +498,8 @@ void DrawGopGnuplot( GraphData ctx, int first, int last, double s,
  */
 void EndPageGnuplot( GraphData ctx )
 {
+    if (!ctx) return;
+
     if (ctx->is_lastwindow) {
 	if (ctx->output_type == GRF_X) 
 	    fprintf( ctx->fp, 
@@ -433,28 +513,38 @@ void EndPageGnuplot( GraphData ctx )
 void HeaderGraph( GraphData ctx, char *protocol_name, char *title_string, 
 		  char *units )
 {
+    if (!ctx) return;
+
     (*ctx->header)( ctx, protocol_name, title_string, units );
 }
 
 void HeaderForGopGraph( GraphData ctx, char *protocol_name, 
 			char *title_string, char *units )
 {
+    if (!ctx) return;
+
     (*ctx->headergop)( ctx, protocol_name, title_string, units );
 }
 
 void DrawGraph( GraphData ctx, int first, int last, double s, double r )
 {
+    if (!ctx) return;
+
     (*ctx->draw)( ctx, first, last, s, r ) ;
 }
 
 void DrawGraphGop( GraphData ctx, int first, int last, double s, double r, 
 		   int nsizes, int *sizelist )
 {
+    if (!ctx) return;
+
     (*ctx->drawgop)( ctx, first, last, s, r, nsizes, sizelist ) ;
 }
 
 void EndPageGraph( GraphData ctx )
 {
+    if (!ctx) return;
+
     (*ctx->endpage)( ctx );
 }
 
@@ -475,7 +565,18 @@ GraphData SetupGraph( int *argc, char *argv[] )
     new = (GraphData)malloc(sizeof(struct _GraphData));    if (!new)return 0;;
 
     filename[0] = 0;
-    isgnu = SYArgHasName( argc, argv, 1, "-gnuplot" );
+    /* Set default.  The gnuplot isn't as nice (separate file for data) */
+    isgnu = 0;
+#ifdef FOO
+#if GRAPHICS_PGM == gnuplot
+    isgnu = 1;
+#else    
+    isgnu = 0;
+#endif
+#endif
+    if (SYArgHasName( argc, argv, 1, "-gnuplot" )) isgnu = 1;
+    if (SYArgHasName( argc, argv, 1, "-cit" )) isgnu = 0;
+
     if (!isgnu) {
 	if ((isgnu = SYArgHasName( argc, argv, 1, "-gnuploteps" ))) {
 	    output_type = GRF_EPS;
@@ -486,6 +587,12 @@ GraphData SetupGraph( int *argc, char *argv[] )
 	    output_type = GRF_PS;
 	};
     }
+    if (!isgnu) {
+	if ((isgnu = SYArgHasName( argc, argv, 1, "-gnuplotgif" ))) {
+	    output_type = GRF_GIF;
+	};
+    }
+
     if (SYArgHasName( argc, argv, 1, "-cit" )) isgnu = 0;
     if (SYArgGetString( argc, argv, 1, "-fname", filename, 1024 ) &&
 	__MYPROCID == 0) {
@@ -537,18 +644,20 @@ GraphData SetupGraph( int *argc, char *argv[] )
 	new->draw	= DrawCIt;
 	new->drawgop    = DrawGopCIt;
 	new->endpage    = EndPageCIt;
+	new->endgraph   = EndGraphCIt;
 	new->fpdata	= new->fp;
 	new->fname2	= 0;
     }
     else {
 	char filename2[256];
-	new->header	    = HeaderGnuplot;
-	new->dataout    = DataoutGraph;
-	new->headergop  = HeaderForGopGnuplot;
-	new->dataoutgop = DataoutGraphForGop;
-	new->draw	    = DrawGnuplot;
-	new->drawgop    = DrawGopGnuplot;
-	new->endpage    = EndPageGnuplot;
+	new->header	= HeaderGnuplot;
+	new->dataout	= DataoutGraph;
+	new->headergop	= HeaderForGopGnuplot;
+	new->dataoutgop	= DataoutGraphForGop;
+	new->draw	= DrawGnuplot;
+	new->drawgop	= DrawGopGnuplot;
+	new->endpage	= EndPageGnuplot;
+	new->endgraph   = EndGraphGnuplot;
 	if (filename[0]) {
 	    /* Try to remove the extension, if any, from the filename */
 	    char *p;
@@ -563,12 +672,16 @@ GraphData SetupGraph( int *argc, char *argv[] )
 	else {
 	    strcpy( filename2, "mppout.gpl" );
 	}
-	new->fpdata	    = fopen( filename2, "a" );
-	if (!new->fpdata) {
-	    fprintf( stderr, "Could not open file %s\n\
+	if (__MYPROCID == 0) {
+	    new->fpdata	    = fopen( filename2, "a" );
+	    if (!new->fpdata) {
+		fprintf( stderr, "Could not open file %s\n\
 used for holding data for GNUPLOT\n", filename2 );
-	    return 0;
+		return 0;
+	    }
 	}
+	else 
+	    new->fpdata   = 0;
 	new->fname2 = (char *)malloc((unsigned)(strlen(filename2 ) + 1 ));
 	strcpy( new->fname2, filename2 );
     }
@@ -577,5 +690,29 @@ used for holding data for GNUPLOT\n", filename2 );
 
 void DataScale( GraphData ctx, int isLog )
 {
+    if (!ctx) return;
+
     ctx->is_log = isLog;
 }
+
+void EndGraph( GraphData ctx )
+{
+    if (!ctx) return;
+
+    (*ctx->endgraph)( ctx );
+}
+
+void EndGraphCIt( GraphData ctx )
+{
+    if (!ctx) return;
+
+    if (ctx->fp && ctx->fp != stdout) fclose( ctx->fp );
+}
+
+void EndGraphGnuplot( GraphData ctx )
+{
+    if (!ctx) return;
+
+    if (ctx->fpdata)                      fclose( ctx->fpdata );
+    if (ctx->fp && ctx->fp != stdout)     fclose( ctx->fp );
+}
