@@ -2,9 +2,7 @@
 #include <stdio.h>
 #include "test.h"
 
-int main( argc, argv )
-int argc;
-char **argv;
+int main( int argc, char **argv )
 {
     int              rank, size, i;
     int              data;
