@@ -2,9 +2,7 @@
 #include "mpi.h"
 #include "test.h"
 
-int main(argc, argv)
-int argc;
-char **argv;
+int main( int argc, char **argv)
 {
     int    err = 0;
     void *v;
