@@ -2,9 +2,7 @@
 #include <stdio.h>
 #include "test.h"
 
-int main( argc, argv )
-int  argc;
-char **argv;
+int main( int argc, char **argv )
 {
     int        flag;
     MPI_Status status;
@@ -17,12 +15,16 @@ char **argv;
     }
 
     MPI_Comm_size( MPI_COMM_WORLD, &size );
+    if (size != 2) {
+	printf( "Test must be run with 2 processes\n" );
+	MPI_Abort( MPI_COMM_WORLD, 1 );
+    }
     MPI_Comm_rank( MPI_COMM_WORLD, &rank );
     partner = (rank + 1) % size;
     MPI_Sendrecv( MPI_BOTTOM, 0, MPI_INT, partner, 0,
 		  MPI_BOTTOM, 0, MPI_INT, partner, 0, 
 		  MPI_COMM_WORLD, &status );
-    if (rank == 0) printf( "Test completed\n" );
+    if (rank == 0) printf( " No Errors\n" );
     MPI_Finalize();
     return 0;
 }
