@@ -1,5 +1,6 @@
 #include "mpi.h"
 #include <stdio.h>
+#include <string.h>
 
 #if defined(NEEDS_STDLIB_PROTOTYPES)
 #include "protofix.h"
@@ -9,9 +10,7 @@
    This is a very simple MPI program which can be used to check things
    like the behavior of the ADI or heterogeneous code
  */
-int main( argc, argv )
-int argc;
-char **argv;
+int main( int argc, char **argv )
 {
 char msg[10];
 char smsg[10];
