@@ -4,7 +4,7 @@
 
 
 #include <stdio.h>
-#include <mpi.h>
+#include "mpi.h"
 
 #if defined(NEEDS_STDLIB_PROTOTYPES)
 #include "protofix.h"
