@@ -432,7 +432,7 @@
         SUBROUTINE MPI_ERROR_STRING(ERRORCODE, STRING, RESULTLEN,      &
       &   IERROR) 
         INTEGER ERRORCODE, RESULTLEN, IERROR 
-        CHARACTER*(*) STRING
+        CHARACTER (LEN=*) STRING
         END SUBROUTINE MPI_ERROR_STRING
 !
         SUBROUTINE MPI_FINALIZE(IERROR)
@@ -440,7 +440,7 @@
         END SUBROUTINE MPI_FINALIZE
 !
         SUBROUTINE MPI_GET_PROCESSOR_NAME( NAME, RESULTLEN, IERROR)
-        CHARACTER*(*) NAME
+        CHARACTER (LEN=*) NAME
         INTEGER RESULTLEN,IERROR
         END SUBROUTINE MPI_GET_PROCESSOR_NAME
 !
