@@ -151,6 +151,11 @@
           MODULE PROCEDURE MPI_FILE_WRITE_SHARED_T
         END INTERFACE ! MPI_FILE_WRITE_SHARED
 
+        PUBLIC :: MPI_SIZEOF
+        INTERFACE MPI_SIZEOF
+           MODULE PROCEDURE MPI_SIZEOF_T
+        END INTERFACE ! MPI_SIZEOF
+
         CONTAINS
  
 ! Fortran bindings
@@ -165,6 +170,13 @@
  
 ! Miscellany
  
+        SUBROUTINE MPI_SIZEOF_T( X, SIZE, IERROR )
+        <type> X(*)
+        INTEGER SIZE, IERROR
+        IERROR = 0
+        SIZE = <typesize>
+        END SUBROUTINE MPI_SIZEOF_T
+
 ! I/O
 !
         SUBROUTINE MPI_FILE_IREAD_T(FH, BUF, COUNT, DATATYPE, REQUEST, &
@@ -453,4 +465,5 @@
         CALL MPI_FILE_WRITE_SHARED(FH, BUF, COUNT, DATATYPE, STATUS,   &
       &   IERROR) 
         END SUBROUTINE MPI_FILE_WRITE_SHARED_T
+
         END MODULE MPI2__<type>_v
