@@ -21,8 +21,8 @@ int main( int argc, char *argv[])
     char processor_name[MPI_MAX_PROCESSOR_NAME];
 
     MPI_Init(&argc,&argv);
-	
-	MPI_Pcontrol( 0 );
+
+        MPI_Pcontrol( 0 );
 
     MPI_Comm_size(MPI_COMM_WORLD,&numprocs);
     MPI_Comm_rank(MPI_COMM_WORLD,&myid);
@@ -50,59 +50,55 @@ int main( int argc, char *argv[])
     event4b = MPE_Log_get_event_number(); 
 
     if (myid == 0) {
-	MPE_Describe_state(event1a, event1b, "Broadcast", "red");
-	MPE_Describe_state(event2a, event2b, "Compute",   "blue");
-	MPE_Describe_state(event3a, event3b, "Reduce",    "green");
-	MPE_Describe_state(event4a, event4b, "Sync",      "orange");
+        MPE_Describe_state(event1a, event1b, "Broadcast", "red");
+        MPE_Describe_state(event2a, event2b, "Compute",   "blue");
+        MPE_Describe_state(event3a, event3b, "Reduce",    "green");
+        MPE_Describe_state(event4a, event4b, "Sync",      "orange");
     }
 
-    if (myid == 0) 
-    {
-	n = 1000000;
-	startwtime = MPI_Wtime();
+    if (myid == 0) {
+        n = 1000000;
+        startwtime = MPI_Wtime();
     }
     MPI_Barrier(MPI_COMM_WORLD);
 
-	MPI_Pcontrol( 1 );
-	/*
+        MPI_Pcontrol( 1 );
+        /*
     MPE_Start_log();
-	*/
+        */
 
-    for (j = 0; j < 5; j++)
-    {
-	MPE_Log_event(event1a, 0, "start broadcast");
-	MPI_Bcast(&n, 1, MPI_INT, 0, MPI_COMM_WORLD);
-	MPE_Log_event(event1b, 0, "end broadcast");
-    
-	MPE_Log_event(event4a,0,"Start Sync");
-	MPI_Barrier(MPI_COMM_WORLD);
-	MPE_Log_event(event4b,0,"End Sync");
+    for (j = 0; j < 5; j++) {
+        MPE_Log_event(event1a, 0, NULL);
+        MPI_Bcast(&n, 1, MPI_INT, 0, MPI_COMM_WORLD);
+        MPE_Log_event(event1b, 0, NULL);
 
-	MPE_Log_event(event2a, 0, "start compute");
-	h   = 1.0 / (double) n;
-	sum = 0.0;
-	for (i = myid + 1; i <= n; i += numprocs)
-	{
-	    x = h * ((double)i - 0.5);
-	    sum += f(x);
-	}
-	mypi = h * sum;
-	MPE_Log_event(event2b, 0, "end compute");
+        MPE_Log_event(event4a, 0, NULL);
+        MPI_Barrier(MPI_COMM_WORLD);
+        MPE_Log_event(event4b, 0, NULL);
 
-	MPE_Log_event(event3a, 0, "start reduce");
-	MPI_Reduce(&mypi, &pi, 1, MPI_DOUBLE, MPI_SUM, 0, MPI_COMM_WORLD);
-	MPE_Log_event(event3b, 0, "end reduce");
+        MPE_Log_event(event2a, 0, NULL);
+        h   = 1.0 / (double) n;
+        sum = 0.0;
+        for (i = myid + 1; i <= n; i += numprocs) {
+            x = h * ((double)i - 0.5);
+            sum += f(x);
+        }
+        mypi = h * sum;
+        MPE_Log_event(event2b, 0, NULL);
+
+        MPE_Log_event(event3a, 0, NULL);
+        MPI_Reduce(&mypi, &pi, 1, MPI_DOUBLE, MPI_SUM, 0, MPI_COMM_WORLD);
+        MPE_Log_event(event3b, 0, NULL);
     }
 /*
     MPE_Finish_log("cpilog");
 */
 
-    if (myid == 0)
-    {
-	endwtime = MPI_Wtime();
-	printf("pi is approximately %.16f, Error is %.16f\n",
-	       pi, fabs(pi - PI25DT));
-	printf("wall clock time = %f\n", endwtime-startwtime);
+    if (myid == 0) {
+        endwtime = MPI_Wtime();
+        printf("pi is approximately %.16f, Error is %.16f\n",
+               pi, fabs(pi - PI25DT));
+        printf("wall clock time = %f\n", endwtime-startwtime);
     }
     MPI_Finalize();
     return(0);
