@@ -26,6 +26,7 @@ import base.io.MixedDataOutput;
 import base.topology.Line;
 import base.topology.Arrow;
 import base.topology.State;
+import base.topology.Event;
 
 // Composite should be considered as an InfoBox of Primitive[]
 
@@ -35,9 +36,6 @@ public class Composite extends Drawable
 {
     private static final int INIT_BYTESIZE   = 2  /* primes.length */ ; 
 
-    private static final DrawOrderComparator DRAWING_ORDER
-                                             = new DrawOrderComparator();
-
     private   Primitive[]      primes;
     private   int              last_prime_idx;
 
@@ -163,8 +161,8 @@ public class Composite extends Drawable
     {
         int primes_length, idx;
 
-        // Save the Lists in Increasing Starttime order
-        Arrays.sort( primes, DRAWING_ORDER );
+        // Save the Lists in Increasing Starttime order, ie drawing order.
+        Arrays.sort( primes, Drawable.INCRE_STARTTIME_ORDER );
 
         super.writeObject( outs );
 
@@ -493,6 +491,31 @@ public class Composite extends Drawable
                            tStart, (float) iStart, tFinal, (float) iFinal );
     }
 
+    public  int  drawEvent( Graphics2D g, CoordPixelXform coord_xform,
+                            Map map_line2row, DrawnBoxSet drawn_boxes,
+                            ColorAlpha color )
+    {
+        Coord  vtx;
+        vtx = this.getStartVertex();
+
+        double tPoint;
+        tPoint = vtx.time;  /* different from Shadow */
+
+        int    rowID;
+        float  rPeak, rStart, rFinal;
+        rowID  = ( (Integer)
+                   map_line2row.get( new Integer(vtx.lineID) )
+                 ).intValue();
+        // rPeak  = (float) rowID + NestingStacks.getHalfInitialNestingHeight();
+        rPeak  = (float) rowID - 0.25f;
+        rStart = (float) rowID - 0.5f;
+        rFinal = rStart + 1.0f;
+
+        return Event.draw( g, color, null, coord_xform,
+                           drawn_boxes.getLastEventPos( rowID ),
+                           tPoint, rPeak, rStart, rFinal );
+    }
+
     /*
         0.0f < nesting_ftr <= 1.0f
     */
@@ -552,6 +575,27 @@ public class Composite extends Drawable
                                    tStart, rStart, tFinal, rFinal );
     }
 
+    public  boolean isPixelAtEvent( CoordPixelXform coord_xform,
+                                    Map map_line2row, Point pix_pt )
+    {
+        Coord  vtx;
+        vtx = this.getStartVertex();
+
+        double tPoint;
+        tPoint = vtx.time;  /* different from Shadow */
+
+        int    rowID;
+        float  rStart, rFinal;
+        rowID  = ( (Integer)
+                   map_line2row.get( new Integer(vtx.lineID) )
+                 ).intValue();
+        rStart = (float) rowID - 0.5f;
+        rFinal = rStart + 1.0f;
+
+        return Event.containsPixel( coord_xform, pix_pt,
+                                    tPoint, rStart, rFinal );
+    }
+
     public boolean containSearchable()
     {
         return super.getCategory().isVisiblySearchable();
