@@ -369,42 +369,6 @@ public class InputLog extends logformat.clog2.InputLog
         return null;
     }
 
-    public Category getShadowCategoryForTopology( final Topology aTopo )
-    {
-        Category   type;
-        ColorAlpha yellow_opaque = new ColorAlpha( ColorAlpha.yellow,
-                                                   ColorAlpha.OPAQUE );
-        ColorAlpha white_opaque  = new ColorAlpha( ColorAlpha.white,
-                                                   ColorAlpha.OPAQUE );
-        ColorAlpha white_near_opaque = new ColorAlpha( ColorAlpha.white,
-                                                       ColorAlpha.NEAR_OPAQUE );
-        if ( aTopo.isEvent() ) {
-            type = new Category( -1, "Preview_" + aTopo.toString(),
-                                 aTopo, white_near_opaque, 5 );
-            /*
-            type.setInfoKeys( "num_real_objs=%d\ntime_error=%E\n" );
-            */
-            return type;
-        }
-        else if ( aTopo.isArrow() ) {
-            type = new Category( -2, "Preview_" + aTopo.toString(),
-                                 aTopo, yellow_opaque, 5 );
-            /*
-            type.setInfoKeys( "num_real_objs=%d\ntime_error=%E\nmsg_size=%d\n" );
-            */
-            return type;
-        }
-        else if ( aTopo.isState() ) {
-            type = new Category( -3, "Preview_" + aTopo.toString(),
-                                 aTopo, white_near_opaque, 5 );
-            /*
-            type.setInfoKeys( "num_real_objs=%d\ntime_error=%E\n" );
-            */
-            return type;
-        }
-        return null;
-    }
-
     // getNextCategory() is called after peekNextKind() returns Kind.CATEGORY
     public Category getNextCategory()
     {
