@@ -1,5 +1,5 @@
 /*
- *  $Id: chflow.c,v 1.7 2000/08/09 22:29:36 gropp Exp $
+ *
  *
  *  (C) 1996 by Argonne National Laboratory and Mississipi State University.
  *      All rights reserved.  See COPYRIGHT in top-level directory.
@@ -44,11 +44,13 @@ void MPID_SendFlowPacket( int partner )
 
 }
 
-void MPID_RecvFlowPacket( in_pkt, partner )
-MPID_PKT_T *in_pkt;
-int        partner;
+void MPID_RecvFlowPacket( 
+	MPID_PKT_T *in_pkt,
+	int        partner)
 {
+#ifdef MPID_FLOW_CONTROL
     MPID_PKT_FLOW_T  *pkt = (MPID_PKT_FLOW_T *)in_pkt;
+#endif
 
     DEBUG_PRINT_MSG("- Receiving flow control packet");
     MPID_FLOW_MEM_GET(pkt,partner);
@@ -57,8 +59,9 @@ int        partner;
 #endif
 }
 
-void MPID_FlowSetup( buf_thresh, mem_thresh )
-int buf_thresh, mem_thresh;
+void MPID_FlowSetup( 
+	int buf_thresh, 
+	int mem_thresh )
 {
     int i;
 
