@@ -72,6 +72,8 @@ void MPID_IrecvDatatype ( struct MPIR_COMMUNICATOR *, void *, int,
 			  struct MPIR_DATATYPE *, 
 			  int, int, int, MPI_Request, int * );
 
+void MPID_Status_set_bytes( MPI_Status *, int );
+
 /* Pack and unpack support */
 void MPID_Msg_rep ( struct MPIR_COMMUNICATOR *, int, 
 		    struct MPIR_DATATYPE *, MPID_Msgrep_t *, 
@@ -106,12 +108,18 @@ int MPID_CommFree ( struct MPIR_COMMUNICATOR * );
  * These are often defined as simple macros.  These prototypes show how
  * they should be defined if they are routines.
  */
+#ifdef __cplusplus
+extern "C" {
+#endif
 #ifndef MPID_Wtime
 void MPID_Wtime ( double * );
 #endif
 #ifndef MPID_Wtick
 void MPID_Wtick ( double * );
 #endif
+#ifdef __cplusplus
+};
+#endif
 
 /* 
  * These are debugging commands; they are exported so that the command-line
