@@ -1129,6 +1129,7 @@ P4VOID zap_p4_processes( void )
     while (n--)
     {
 	if (pid_list[n] > 0) {
+	    p4_dprintfl(99,"ZAPPING: %d\n",pid_list[n]);
 	    kill(pid_list[n], SIGINT);
 	}
     }
@@ -1149,8 +1150,17 @@ P4VOID zap_remote_p4_processes( void )
     my_id = p4_get_my_id();
 
     dest_pi = get_proc_info(0);
+    /* It was reported that setting the prev_hostname and prev_port 
+       caused the code to fail to kill the remote listeners (it only
+       killed the local slaves).
+       (REQ #9145)
+    */
+    /*
     strcpy(prev_hostname,dest_pi->host_name);
     prev_port = dest_pi->port;
+    */
+    strcpy( prev_hostname,"");
+    prev_port = 0;
     for (i = 0; i < p4_global->num_in_proctable; i++) {
 	dest_id = i;
 	if (dest_id != my_id) {
@@ -1522,7 +1532,10 @@ beowulf_init(void)
 	  strncpy(pe->slave_full_pathname, "self", 4);
       else
 	  pe->slave_full_pathname[cnt] = 0;
-      strncpy(pe->username, pwent->pw_name, 10);
+      if (strlen(pwent->pw_name) >= sizeof(pe->username)) {
+	  p4_error("beowulf_init: username is too long",0);
+      }
+      strncpy(pe->username, pwent->pw_name, sizeof(pe->username)-1);
       pe++;
   }
 
