@@ -1,7 +1,8 @@
 #ifndef CHCONFIG
 #define CHCONFIG
 
-#define MPID_HAS_HETERO 
+/* Turn off support for heterogeneity */
+/* #define MPID_HAS_HETERO  */
 
 /* This makes chbrndv.c use memcpy for rendezvous messages to self */
 #define MPID_RNDV_SELF
@@ -26,7 +27,7 @@
  */
 
 /* Put macro-definitions of routines here */
-int p4_proc_info ANSI_ARGS(( int, char **, char ** ));
+int p4_proc_info ( int, char **, char ** );
 #define MPID_getpid(i,n,e) p4_proc_info((i),(n),(e))
 
 /* Communicator initialization routines */
