@@ -1,18 +1,16 @@
 #include "p4.h"
 #include "p4_sys.h"
-#include "bnr.h"
 
 /* extern struct fdentry fdtable[MAXFDENTRIES]; */
 
-void peer_msg_handler(char *);
+void p4_peer_msg_handler(char *);
 
-int bm_start(argc, argv)
-int *argc;
-char **argv;
+int bm_start(int *argc, char **argv)
 {
     int bm_switch_port;
     char *s, pgmname[P4_MAX_PGM_LEN];
-    int rc, mygroupid, myjsize, myrank;
+    int rc, myjsize, myrank;
+    BNR_Group mygroup;
 
     setbuf( stdout, NULL );  /* turn off buffering for clients */
 
@@ -21,23 +19,31 @@ char **argv;
     p4_local = alloc_local_bm();
     if (p4_local == NULL)
 	p4_error("p4_initenv: alloc_local_bm failed\n", 0);
-    setup_conntab();
 
-    rc = BNR_Pre_init( peer_msg_handler );  /* specific to mpich-1 */
-    rc = BNR_Init( &mygroupid );
-    rc = BNR_Rank( mygroupid, &myrank );
-    rc = BNR_Size( mygroupid, &myjsize );
+    rc = BNR_Pre_init( p4_peer_msg_handler );  /* specific to mpich-1 */
+    rc = BNR_Init( );
+    rc = BNR_Get_group( &mygroup );
+    rc = BNR_Get_rank( mygroup, &myrank );
+    rc = BNR_Get_size( mygroup, &myjsize );
+
+    p4_dprintfl(10,"IGNORING SIGPIPE\n");
+    SIGNAL_P4(SIGPIPE,SIG_IGN);
     
     sprintf(whoami_p4, "p%d_%d", myrank, (int)getpid());
     p4_global->num_in_proctable = myjsize; /* there really isn't any proctable  */
 
     p4_local->my_id	    = myrank;
-    p4_local->my_job	    = mygroupid;    /* default jobid for now */
+    p4_local->my_job	    = BNR_Get_group_id( mygroup );  /* default jobid for now */
+
+    setup_conntab();
 
     /* get fd for talking to the manager from the environment, where he put it after
        acquiring it. */
     rc = BNR_Man_msgs_fd( &(p4_local->parent_man_fd) );
 
+#if 0
+    /**********   This is done for us in the p4mpd device  **********/
+
     /* choose a working directory */
     if (strlen(p4_wd) && !chdir(p4_wd))
     {
@@ -51,8 +57,10 @@ char **argv;
 	{
 	    *s = '\0';  /* chg to directory name only */
 	    chdir(pgmname);
+	    /* p4_dprintf("RMB bm_start: CHGING DIR TO %s\n",pgmname); */
 	}
     }
+#endif
 
 #   ifdef SYSV_IPC
     sysv_num_shmids = 0;
@@ -76,25 +84,28 @@ char **argv;
 
     /* big master installing himself */
     install_in_proctable(0, (-1), getpid(), p4_global->my_host_name, 
+			 p4_global->my_host_name, 
 			 0, P4_MACHINE_TYPE, bm_switch_port);
 
+    BNR_Fence( mygroup ); /* to make sure p4 data structures are set before interrupts
+			     can occur */
     return (0);
 }
 
-void peer_msg_handler( msg )
+void p4_peer_msg_handler( msg )
 char *msg;
 {
     char cmd[32] /*, tohostname[MAXLINE]*/;
     char c_torank[32],c_toport[32],c_toipaddr[32];
-    int torank,toport,connection_fd,num_tries,rc,connected,optval;
+    int flags,torank,toport,connection_fd,num_tries,rc,connected,optval;
     int myid = p4_get_my_id();
     unsigned int toipaddr;
     struct sockaddr_in sa;
 
-    p4_dprintfl(077,"peer_msg_handler entered with msg :%s:\n",msg );
+    p4_dprintfl(077,"p4_peer_msg_handler entered with msg :%s:\n",msg );
     if (strncmp(msg,"connect_to_me-",14) != 0)
     {
-	p4_dprintfl(077,"invalid msg in peer_msg_handler :%s:\n",msg);
+	p4_dprintf("invalid msg in p4_peer_msg_handler :%s:\n",msg);
 	return;
     }
     sscanf(msg,"%[^-]-%[^-]-%[^-]-%s",cmd,c_torank,c_toipaddr,c_toport);
@@ -108,57 +119,79 @@ char *msg;
 
     if (p4_local->conntab[torank].type == CONN_REMOTE_EST)
     {
-	p4_dprintfl(077, "peer_msg_handler: already conn'd to %d\n", torank);
+	p4_dprintfl(077, "p4_peer_msg_handler: already conn'd to %d\n", torank);
 	return;
     }
     if (p4_global->dest_id[myid] == torank)  /* already connecting */
     {
 	if (myid > torank)
 	{
-	    p4_dprintfl(077, "peer_msg_handler: already making conn to %d\n", torank);
+	    p4_dprintfl(077, "p4_peer_msg_handler: already making conn to %d\n", torank);
 	    return;
 	}
     }
 
-    SYSCALL_P4(connection_fd, socket(AF_INET, SOCK_STREAM, 0));
-    if (connection_fd < 0)
-	p4_error("peer_msg_handler socket", connection_fd);
-    optval = 1;
-    SYSCALL_P4(rc, setsockopt(connection_fd,IPPROTO_TCP,TCP_NODELAY,(char *) &optval,sizeof(optval)));
     connected = 0;
     num_tries = 3;
     while (!connected && num_tries) {
+	SYSCALL_P4(connection_fd, socket(AF_INET, SOCK_STREAM, 0));
+	if (connection_fd < 0)
+	    p4_error("p4_peer_msg_handler socket", connection_fd);
 	SYSCALL_P4(rc, connect(connection_fd, (struct sockaddr *) &sa,
 			       sizeof(struct sockaddr_in)));
 	if (rc < 0)
 	{
+	    close(connection_fd);
 	    p4_dprintfl( 077, "Connect failed; closed socket %d\n", connection_fd );
 	    if (--num_tries)
 	    {
-		p4_dprintfl(077,"peer_msg_handler: connect to %s failed; will try %d more times \n",c_toipaddr,num_tries);
+		p4_dprintfl(077,"p4_peer_msg_handler: connect to %s failed; will try %d more times \n",c_toipaddr,num_tries);
 		sleep(1);
 	    }
 	}
 	else
 	{
 	    connected = 1;
-	    p4_dprintfl(077,"peer_msg_handler: connected to %s\n",c_toipaddr);
+	    p4_dprintfl(077,"p4_peer_msg_handler: connected to %s\n",c_toipaddr);
 	}
 
     }
+    if ( ! connected)
+    {
+        p4_dprintf("p4_peer_msg_handler: failed connect to %s\n",c_toipaddr);
+        p4_error("failed to connnect",-1);
+    }
+
+    flags = fcntl(connection_fd, F_GETFL, 0);
+    if (flags < 0)
+        p4_error("p4_bm fcntl1", flags); 
+#   if defined(HP)
+    flags |= O_NONBLOCK;
+#   else
+    flags |= O_NDELAY;
+    p4_dprintfl(90, "p4_bm: setting ndelay for %d\n",connection_fd);
+#   endif   
+#   if defined(RS6000)
+    flags |= O_NONBLOCK;
+#   endif   
+    flags = fcntl(connection_fd, F_SETFL, flags); 
+    if (flags < 0)
+        p4_error("p4_bm fcntl2", flags); 
+    optval = 1;
+    SYSCALL_P4(rc, setsockopt(connection_fd,IPPROTO_TCP,TCP_NODELAY,(char *) &optval,sizeof(optval)));
 
     p4_local->conntab[torank].type = CONN_REMOTE_EST;
     p4_local->conntab[torank].port = connection_fd;
     p4_local->conntab[torank].same_data_rep = P4_TRUE;
-/*    p4_dprintfl(077, "peer_msg_handler: connected after %d tries, connection_fd=%d host = %s\n",
+/*    p4_dprintfl(077, "p4_peer_msg_handler: connected after %d tries, connection_fd=%d host = %s\n",
       num_tries, connection_fd, tohostname); */
-    p4_dprintfl(077, "peer_msg_handler: connected after %d tries, connection_fd=%d\n",
+    p4_dprintfl(077, "p4_peer_msg_handler: connected after %d tries, connection_fd=%d\n",
 		num_tries, connection_fd);
 
     /* We're connected, so we can add this connection to the table */
     p4_dprintfl(077, "marked as established fd=%d torank=%d\n",
 		connection_fd, torank);
-    p4_dprintfl(077,"peer_msg_handler done\n" );
+    p4_dprintfl(077,"p4_peer_msg_handler done\n" );
 }
 
 
@@ -352,10 +385,10 @@ struct p4_procgroup *pg;
     if (!(p4_global->local_communication_only))
     {
 	listener_fd = p4_global->listener_fd;
-	listener_info = alloc_listener_info();
+	listener_info = alloc_listener_info(1);
 	l = listener_info;
 	get_pipe(&end_1, &end_2); /* used even by thread listener */
-	l->slave_fd = end_2;
+	l->slave_fd[0] = end_2;
     }
 #   endif
 
@@ -403,6 +436,7 @@ struct p4_procgroup *pg;
 	switch_port = p4_n_to_i(bm_msg.switch_port);
 	/* big master installing local slaves */
 	install_in_proctable(0, port, slave_pid, bm_msg.host_name, 
+			     bm_msg.local_name, 
 			     slave_idx, P4_MACHINE_TYPE, switch_port);
 	p4_global->local_slave_count++;
     }
@@ -503,6 +537,7 @@ struct p4_procgroup *pg;
 
 	/* master installing local slaves */
 	install_in_proctable(0, p4_global->listener_port, slave_pid,
+			     p4_global->my_host_name, 
 			     p4_global->my_host_name, 
 			     slave_idx, P4_MACHINE_TYPE,
 			     p4_global->proctable[0].switch_port);
@@ -548,7 +583,7 @@ struct p4_procgroup *pg;
 	    /* Inside listener */
 	    p4_local = alloc_local_listener();
 	    l->listening_fd = listener_fd;
-	    l->slave_fd = end_2;
+	    l->slave_fd[0] = end_2;
 	    close(end_1);
 	    {
 		/* exec external listener process */
@@ -562,7 +597,7 @@ struct p4_procgroup *pg;
 		    sprintf(dbg_c, "%d", p4_debug_level);
 		    sprintf(max_c, "%d", p4_global->max_connections);
 		    sprintf(lfd_c, "%d", l->listening_fd);
-		    sprintf(sfd_c, "%d", l->slave_fd);
+		    sprintf(sfd_c, "%d", l->slave_fd[0]);
 		    p4_dprintfl(70, "exec %s %s %s %s %s\n",
 				listener_prg, dbg_c, max_c, lfd_c, sfd_c);
 		    execlp(listener_prg, listener_prg,
@@ -636,7 +671,7 @@ struct p4_procgroup *pg;
 	strcpy(p4_global->my_host_name,pg->entries[0].host_name);
 	strcpy(p4_global->proctable[0].host_name,pg->entries[0].host_name);
     }
-    get_qualified_hostname(p4_global->proctable[0].host_name);
+    get_qualified_hostname(p4_global->proctable[0].host_name, HOSTNAME_LEN);
     p4_dprintfl(10,"hostname for first entry in proctable is %s\n",
 		p4_global->proctable[0].host_name);
     p4_global->proctable[0].group_id = 0;
@@ -650,21 +685,22 @@ struct p4_procgroup *pg;
 		       p4_global->proctable[0].host_name);
 	    else
 		strcpy(p4_global->proctable[ptidx].host_name,pe->host_name);
-	    get_qualified_hostname(p4_global->proctable[ptidx].host_name);
+	    get_qualified_hostname(p4_global->proctable[ptidx].host_name,
+				   HOSTNAME_LEN);
 	    p4_global->proctable[ptidx].group_id = i;
 #           ifdef CAN_DO_SOCKET_MSGS
 	    {
 	    struct hostent *hp = 
 		gethostbyname_p4(p4_global->proctable[ptidx].host_name);
-	    struct sockaddr_in *listener = 
+	    struct sockaddr_in *listener_sin = 
 		&p4_global->proctable[ptidx].sockaddr;
-	    bzero( (P4VOID*) listener, sizeof(struct sockaddr_in) );
-	    bcopy((P4VOID *) hp->h_addr, (P4VOID *)&listener->sin_addr, 
+	    bzero( (P4VOID*) listener_sin, sizeof(struct sockaddr_in) );
+	    bcopy((P4VOID *) hp->h_addr, (P4VOID *)&listener_sin->sin_addr, 
 		  hp->h_length);
-	    listener->sin_family = hp->h_addrtype;
+	    listener_sin->sin_family = hp->h_addrtype;
 	    /* Set a dummy port so that we can detect that the field
 	       has been initialized */
-	    listener->sin_port = 1;
+	    listener_sin->sin_port = 1;
 	    }
 #           endif
 	    ptidx++;
