@@ -32,6 +32,10 @@
 #include <signal.h>
 #endif
 
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+
 #define p2p_dprintf printf
 
 #if defined(USE_MMAP)
@@ -539,6 +543,7 @@ void p2p_yield( void )
 		kind = 0;
 	    }
 	}
+	first_call = 0;
     }
     switch (kind) {
     case 0: return;
