@@ -1,4 +1,4 @@
-#include <globus_dc.h>
+#include "chconfig.h"
 #include "globdev.h"
 #include "reqalloc.h"
 #include "queue.h" /* for MPID_Dequeue() */
