@@ -163,6 +163,8 @@ int main( int argc, char *argv[] )
 	case 'l':
 	    strncpy( c_listener_port, optarg, MAXLINE );	break;
 	case 'b':
+	    /* Note that mpd2 uses -d for this, but -d is alread
+	       used in mpd1 for debug.  Sigh. */
             strncpy( c_backgrounded, "yes", MAXLINE );          break;
 	case 'e':
             strncpy( c_no_execute, "yes", MAXLINE );            break;
@@ -594,8 +596,11 @@ static int get_config( char *filename )
     }
     mpd_getval( "password", mpd_passwd );
     if ( mpd_passwd[0] == '\0' ) {
-	mpdprintf( 1, "get_config: no passwd in config file\n" );
-	return( -1 );
+	mpd_getval( "secretword", mpd_passwd );
+	if (mpd_passwd[0] == '\0') {
+	    mpdprintf( 1, "get_config: no passwd in config file\n" );
+	    return( -1 );
+	}
     }
     mpd_getval( "working_directory", working_directory );
     mpd_getval( "lhs_host", lhshost );
