@@ -1,5 +1,5 @@
 /*
- *  $Id: sbcnst2.c,v 1.8 2002/03/07 15:33:51 gropp Exp $
+ *  $Id: sbcnst2.c,v 1.9 2003/03/18 17:17:40 gropp Exp $
  *
  *  (C) 1993 by Argonne National Laboratory and Mississipi State University.
  *      See COPYRIGHT in top-level directory.
@@ -188,7 +188,7 @@ void MPID_SBiAllocate(
 	int nb )
 {
     char          *p, *p2;
-    int           i, headeroffset, n;
+    int           i, headeroffset;
     MPID_SBiAlloc *header;
 
 /* printf( "Allocating %d blocks of size %d\n", nb, bsize ); */
@@ -204,10 +204,12 @@ if (!p) {
    }
 /* Initialize the data to an invalid value */
 /* Eventually this will be conditional on debugging */
-n = bsize * nb + headeroffset;
 #ifdef DEBUG
-for (i=0; i<n; i++) 
-    p[i] = (char)0xea;
+ { int n; 
+ n = bsize * nb + headeroffset;
+ for (i=0; i<n; i++) 
+     p[i] = (char)0xea;
+ }
 #endif
 
 header          = (MPID_SBiAlloc *)p;
