@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_nfs.c,v 1.3 2002/10/24 17:00:45 gropp Exp $
+ *   $Id: ad_nfs.c,v 1.4 2004/10/04 15:50:51 robl Exp $
  *
  *   Copyright (C) 2001 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -22,16 +22,16 @@ struct ADIOI_Fns_struct ADIO_NFS_operations = {
     ADIOI_GEN_SetInfo, /* SetInfo */
     ADIOI_NFS_ReadStrided, /* ReadStrided */
     ADIOI_NFS_WriteStrided, /* WriteStrided */
-    ADIOI_NFS_Close, /* Close */
+    ADIOI_GEN_Close, /* Close */
     ADIOI_NFS_IreadContig, /* IreadContig */
     ADIOI_NFS_IwriteContig, /* IwriteContig */
     ADIOI_NFS_ReadDone, /* ReadDone */
     ADIOI_NFS_WriteDone, /* WriteDone */
     ADIOI_NFS_ReadComplete, /* ReadComplete */
     ADIOI_NFS_WriteComplete, /* WriteComplete */
-    ADIOI_NFS_IreadStrided, /* IreadStrided */
-    ADIOI_NFS_IwriteStrided, /* IwriteStrided */
+    ADIOI_GEN_IreadStrided, /* IreadStrided */
+    ADIOI_GEN_IwriteStrided, /* IwriteStrided */
     ADIOI_GEN_Flush, /* Flush */
-    ADIOI_NFS_Resize, /* Resize */
+    ADIOI_GEN_Resize, /* Resize */
     ADIOI_GEN_Delete, /* Delete */
 };
