@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_pfs_flush.c,v 1.10 2003/04/18 20:14:58 David Exp $    
+ *   $Id: ad_pfs_flush.c,v 1.11 2004/10/04 15:50:57 robl Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -11,24 +11,16 @@
 void ADIOI_PFS_Flush(ADIO_File fd, int *error_code)
 {
     int err, np_total, np_comm;
-#ifndef PRINT_ERR_MSG
     static char myname[] = "ADIOI_PFS_FLUSH";
-#endif
 
 /* fsync is not actually needed in PFS, because it uses something
    called fast-path I/O. However, it doesn't do any harm either. */
     err = fsync(fd->fd_sys);
     if (err == -1) {
-#ifdef MPICH2
-	*error_code = MPIR_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE, myname, __LINE__, MPI_ERR_IO, "**io",
-	    "**io %s", strerror(errno));
-#elif defined(PRINT_ERR_MSG)
-	*error_code =  MPI_ERR_UNKNOWN;
-#else
-	*error_code = MPIR_Err_setmsg(MPI_ERR_IO, MPIR_ADIO_ERROR,
-			      myname, "I/O Error", "%s", strerror(errno));
-	ADIOI_Error(fd, *error_code, myname);	    
-#endif
+	*error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					   myname, __LINE__, MPI_ERR_IO,
+					   "**io",
+					   "**io %s", strerror(errno));
     }
     else *error_code = MPI_SUCCESS;
 
