@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_pfs_iwrite.c,v 1.6 2002/10/24 17:00:52 gropp Exp $    
+ *   $Id: ad_pfs_iwrite.c,v 1.11 2004/10/04 15:50:57 robl Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -15,9 +15,7 @@ void ADIOI_PFS_IwriteContig(ADIO_File fd, void *buf, int count,
     long *id_sys;
     ADIO_Offset off;
     int len, typesize, err;
-#ifndef PRINT_ERR_MSG
     static char myname[] = "ADIOI_PFS_IWRITECONTIG";
-#endif
 
     *request = ADIOI_Malloc_request();
     (*request)->optype = ADIOI_WRITE;
@@ -41,33 +39,26 @@ void ADIOI_PFS_IwriteContig(ADIO_File fd, void *buf, int count,
         /* exceeded the max. no. of outstanding requests. */
 
         /* complete all previous async. requests */
-        ADIOI_Complete_async(&err);
+        ADIOI_Complete_async(error_code);
+	if (error_code != MPI_SUCCESS) return;
 
         /* try again */
 	*id_sys = _iwrite(fd->fd_sys, buf, len);
 
         if ((*id_sys == -1) && (errno == EQNOMID)) {
-#ifdef PRINT_ERR_MSG
-            FPRINTF(stderr, "Error in asynchronous I/O\n");
-            MPI_Abort(MPI_COMM_WORLD, 1);
-#else
-	    *error_code = MPIR_Err_setmsg(MPI_ERR_IO, MPIR_ADIO_ERROR,
-			      myname, "I/O Error", "%s", strerror(errno));
-	    ADIOI_Error(fd, *error_code, myname);	    
+	    *error_code = MPIO_Err_create_code(MPI_SUCCESS,
+					       MPIR_ERR_RECOVERABLE, myname,
+					       __LINE__, MPI_ERR_IO, "**io",
+					       "**io %s", strerror(errno));
 	    return;
-#endif
         }
     }
     else if (*id_sys == -1) {
-#ifdef PRINT_ERR_MSG
-	FPRINTF(stderr, "Unknown errno %d in ADIOI_PFS_IwriteContig\n", errno);
-	MPI_Abort(MPI_COMM_WORLD, 1);
-#else
-	*error_code = MPIR_Err_setmsg(MPI_ERR_IO, MPIR_ADIO_ERROR,
-			         myname, "I/O Error", "%s", strerror(errno));
-	ADIOI_Error(fd, *error_code, myname);	    
+	*error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					   myname, __LINE__, MPI_ERR_IO,
+					   "**io",
+					   "**io %s", strerror(errno));
 	return;
-#endif
     }
 
     if (file_ptr_type == ADIO_INDIVIDUAL) fd->fp_ind += len; 
@@ -79,46 +70,11 @@ void ADIOI_PFS_IwriteContig(ADIO_File fd, void *buf, int count,
 
     fd->fp_sys_posn = -1;   /* set it to null. */
 
-#ifdef PRINT_ERR_MSG
-    *error_code = (*id_sys == -1) ? MPI_ERR_UNKNOWN : MPI_SUCCESS;
-#else
     if (*id_sys == -1) {
-	*error_code = MPIR_Err_setmsg(MPI_ERR_IO, MPIR_ADIO_ERROR,
-			      myname, "I/O Error", "%s", strerror(errno));
-	ADIOI_Error(fd, *error_code, myname);	    
+	*error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					   myname, __LINE__, MPI_ERR_IO,
+					   "**io",
+					   "**io %s", strerror(errno));
     }
     else *error_code = MPI_SUCCESS;
-#endif
-}
-
-
-
-void ADIOI_PFS_IwriteStrided(ADIO_File fd, void *buf, int count, 
-		       MPI_Datatype datatype, int file_ptr_type,
-                       ADIO_Offset offset, ADIO_Request *request, int
-                       *error_code)
-{
-    ADIO_Status status;
-#ifdef HAVE_STATUS_SET_BYTES
-    int typesize;
-#endif
-
-    *request = ADIOI_Malloc_request();
-    (*request)->optype = ADIOI_WRITE;
-    (*request)->fd = fd;
-    (*request)->datatype = datatype;
-    (*request)->queued = 0;
-    (*request)->handle = 0;
-
-/* call the blocking version. It is faster because it does data sieving. */
-    ADIOI_PFS_WriteStrided(fd, buf, count, datatype, file_ptr_type, 
-                            offset, &status, error_code);  
-
-    fd->async_count++;
-#ifdef HAVE_STATUS_SET_BYTES
-    if (*error_code == MPI_SUCCESS) {
-	MPI_Type_size(datatype, &typesize);
-	(*request)->nbytes = count * typesize;
-    }
-#endif
 }
