@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_pfs_open.c,v 1.10 2003/04/18 20:14:59 David Exp $    
+ *   $Id: ad_pfs_open.c,v 1.12 2005/05/23 23:27:43 rross Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -16,9 +16,7 @@ void ADIOI_PFS_Open(ADIO_File fd, int *error_code)
     int perm, amode, old_mask, np_comm, np_total, err, flag;
     char *value;
     struct sattr attr;
-#ifndef PRINT_ERR_MSG
     static char myname[] = "ADIOI_PFS_OPEN";
-#endif
 
     if (fd->perm == ADIO_PERM_NULL) {
 	old_mask = umask(022);
@@ -46,11 +44,12 @@ void ADIOI_PFS_Open(ADIO_File fd, int *error_code)
     MPE_Log_event(1, 0, "start open");
 #endif
     if (np_total == np_comm) 
-	fd->fd_sys = _gopen(fd->filename,amode,fd->iomode,perm);
+	fd->fd_sys = _gopen(fd->filename, amode, M_ASYNC, perm);
     else fd->fd_sys = open(fd->filename, amode, perm);
 #ifdef PROFILE
     MPE_Log_event(2, 0, "end open");
 #endif
+    fd->fd_direct = -1;
 
     if (fd->fd_sys != -1) {
 	value = (char *) ADIOI_Malloc((MPI_MAX_INFO_VAL+1)*sizeof(char));
@@ -87,16 +86,10 @@ void ADIOI_PFS_Open(ADIO_File fd, int *error_code)
     }
 
     if (fd->fd_sys == -1) {
-#ifdef MPICH2
-	*error_code = MPIR_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE, myname, __LINE__, MPI_ERR_IO, "**io",
-	    "**io %s", strerror(errno));
-#elif defined(PRINT_ERR_MSG)
-	*error_code =  MPI_ERR_UNKNOWN;
-#else
-	*error_code = MPIR_Err_setmsg(MPI_ERR_IO, MPIR_ADIO_ERROR,
-			      myname, "I/O Error", "%s", strerror(errno));
-	ADIOI_Error(ADIO_FILE_NULL, *error_code, myname);	    
-#endif
+	*error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					   myname, __LINE__, MPI_ERR_IO,
+					   "**io",
+					   "**io %s", strerror(errno));
     }
     else *error_code = MPI_SUCCESS;
 }
