@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_piofs.c,v 1.3 2002/10/24 17:00:54 gropp Exp $
+ *   $Id: ad_piofs.c,v 1.5 2005/05/23 23:27:43 rross Exp $
  *
  *   Copyright (C) 2001 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -17,21 +17,21 @@ struct ADIOI_Fns_struct ADIO_PIOFS_operations = {
     ADIOI_PIOFS_WriteContig, /* WriteContig */
     ADIOI_GEN_ReadStridedColl, /* ReadStridedColl */
     ADIOI_GEN_WriteStridedColl, /* WriteStridedColl */
-    ADIOI_PIOFS_SeekIndividual, /* SeekIndividual */
+    ADIOI_GEN_SeekIndividual, /* SeekIndividual */
     ADIOI_PIOFS_Fcntl, /* Fcntl */
     ADIOI_PIOFS_SetInfo, /* SetInfo */
     ADIOI_GEN_ReadStrided, /* ReadStrided */
     ADIOI_PIOFS_WriteStrided, /* WriteStrided */
-    ADIOI_PIOFS_Close, /* Close */
-    ADIOI_PIOFS_IreadContig, /* IreadContig */
-    ADIOI_PIOFS_IwriteContig, /* IwriteContig */
-    ADIOI_PIOFS_ReadDone, /* ReadDone */
-    ADIOI_PIOFS_WriteDone, /* WriteDone */
-    ADIOI_PIOFS_ReadComplete, /* ReadComplete */
-    ADIOI_PIOFS_WriteComplete, /* WriteComplete */
-    ADIOI_PIOFS_IreadStrided, /* IreadStrided */
-    ADIOI_PIOFS_IwriteStrided, /* IwriteStrided */
+    ADIOI_GEN_Close, /* Close */
+    ADIOI_FAKE_IreadContig, /* IreadContig */
+    ADIOI_FAKE_IwriteContig, /* IwriteContig */
+    ADIOI_FAKE_IODone, /* ReadDone */
+    ADIOI_FAKE_IODone, /* WriteDone */
+    ADIOI_FAKE_IOComplete, /* ReadComplete */
+    ADIOI_FAKE_IOComplete, /* WriteComplete */
+    ADIOI_FAKE_IreadStrided, /* IreadStrided */
+    ADIOI_FAKE_IwriteStrided, /* IwriteStrided */
     ADIOI_GEN_Flush, /* Flush */
-    ADIOI_PIOFS_Resize, /* Resize */
+    ADIOI_GEN_Resize, /* Resize */
     ADIOI_GEN_Delete, /* Delete */
 };
