@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_pvfs.c,v 1.4 2003/04/15 22:21:37 robl Exp $
+ *   $Id: ad_pvfs.c,v 1.6 2005/05/23 23:27:44 rross Exp $
  *
  *   Copyright (C) 2001 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -17,20 +17,20 @@ struct ADIOI_Fns_struct ADIO_PVFS_operations = {
     ADIOI_PVFS_WriteContig, /* WriteContig */
     ADIOI_GEN_ReadStridedColl, /* ReadStridedColl */
     ADIOI_GEN_WriteStridedColl, /* WriteStridedColl */
-    ADIOI_PVFS_SeekIndividual, /* SeekIndividual */
+    ADIOI_GEN_SeekIndividual, /* SeekIndividual */
     ADIOI_PVFS_Fcntl, /* Fcntl */
     ADIOI_PVFS_SetInfo, /* SetInfo */
     ADIOI_PVFS_ReadStrided, /* ReadStrided */
     ADIOI_PVFS_WriteStrided, /* WriteStrided */
     ADIOI_PVFS_Close, /* Close */
-    ADIOI_PVFS_IreadContig, /* IreadContig */
-    ADIOI_PVFS_IwriteContig, /* IwriteContig */
-    ADIOI_PVFS_ReadDone, /* ReadDone */
-    ADIOI_PVFS_WriteDone, /* WriteDone */
-    ADIOI_PVFS_ReadComplete, /* ReadComplete */
-    ADIOI_PVFS_WriteComplete, /* WriteComplete */
-    ADIOI_PVFS_IreadStrided, /* IreadStrided */
-    ADIOI_PVFS_IwriteStrided, /* IwriteStrided */
+    ADIOI_FAKE_IreadContig, /* IreadContig */
+    ADIOI_FAKE_IwriteContig, /* IwriteContig */
+    ADIOI_FAKE_IODone, /* ReadDone */
+    ADIOI_FAKE_IODone, /* WriteDone */
+    ADIOI_FAKE_IOComplete, /* ReadComplete */
+    ADIOI_FAKE_IOComplete, /* WriteComplete */
+    ADIOI_FAKE_IreadStrided, /* IreadStrided */
+    ADIOI_FAKE_IwriteStrided, /* IwriteStrided */
     ADIOI_PVFS_Flush, /* Flush */
     ADIOI_PVFS_Resize, /* Resize */
     ADIOI_PVFS_Delete, /* Delete */
