@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_pvfs_close.c,v 1.4 2002/10/24 17:00:57 gropp Exp $    
+ *   $Id: ad_pvfs_close.c,v 1.9 2004/10/04 15:51:01 robl Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -11,19 +11,16 @@
 void ADIOI_PVFS_Close(ADIO_File fd, int *error_code)
 {
     int err;
-#ifndef PRINT_ERR_MSG
     static char myname[] = "ADIOI_PVFS_CLOSE";
-#endif
 
     err = pvfs_close(fd->fd_sys);
-#ifdef PRINT_ERR_MSG
-    *error_code = (err == 0) ? MPI_SUCCESS : MPI_ERR_UNKNOWN;
-#else
+    fd->fd_sys = -1;
+
     if (err == -1) {
-	*error_code = MPIR_Err_setmsg(MPI_ERR_IO, MPIR_ADIO_ERROR,
-			      myname, "I/O Error", "%s", strerror(errno));
-	ADIOI_Error(fd, *error_code, myname);	    
+	*error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					   myname, __LINE__, MPI_ERR_IO,
+					   "**io",
+					   "**io %s", strerror(errno));
     }
     else *error_code = MPI_SUCCESS;
-#endif
 }
