@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_pvfs_flush.c,v 1.12 2004/05/20 19:05:17 robl Exp $    
+ *   $Id: ad_pvfs_flush.c,v 1.13 2004/10/04 15:51:08 robl Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -11,9 +11,7 @@
 void ADIOI_PVFS_Flush(ADIO_File fd, int *error_code)
 {
     int err, rank, dummy=0, dummy_in=0;
-#ifndef PRINT_ERR_MSG
     static char myname[] = "ADIOI_PVFS_FLUSH";
-#endif
 
     /* a collective routine: because we do not cache data in PVFS1, one process
      * can initiate the fsync operation and broadcast the result to the others.
@@ -30,16 +28,10 @@ void ADIOI_PVFS_Flush(ADIO_File fd, int *error_code)
     MPI_Bcast(&err, 1, MPI_INT, 0, fd->comm);
 
     if (err == -1) {
-#ifdef MPICH2
-	*error_code = MPIR_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE, myname, __LINE__, MPI_ERR_IO, "**io",
-	    "**io %s", strerror(errno));
-#elif defined(PRINT_ERR_MSG)
-	*error_code = MPI_ERR_UNKNOWN;
-#else /* MPICH-1 */
-	*error_code = MPIR_Err_setmsg(MPI_ERR_IO, MPIR_ADIO_ERROR,
-			      myname, "I/O Error", "%s", strerror(errno));
-	ADIOI_Error(fd, *error_code, myname);	    
-#endif
+	*error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					   myname, __LINE__, MPI_ERR_IO,
+					   "**io",
+					   "**io %s", strerror(errno));
     }
     else *error_code = MPI_SUCCESS;
 }
