@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_delete.c,v 1.8 2002/10/24 17:01:11 gropp Exp $    
+ *   $Id: ad_delete.c,v 1.18 2004/10/04 15:51:23 robl Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -15,18 +15,14 @@
 void ADIOI_GEN_Delete(char *filename, int *error_code)
 {
     int err;
-#ifndef PRINT_ERR_MSG
     static char myname[] = "ADIOI_GEN_DELETE";
-#endif
+
     err = unlink(filename);
-#ifdef PRINT_ERR_MSG
-    *error_code = (err == 0) ? MPI_SUCCESS : MPI_ERR_UNKNOWN;
-#else
     if (err == -1) {
-	*error_code = MPIR_Err_setmsg(MPI_ERR_IO, MPIR_ADIO_ERROR,
-			      myname, "I/O Error", "%s", strerror(errno));
-	ADIOI_Error(MPI_FILE_NULL, *error_code, myname);	    
+	*error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					   myname, __LINE__, MPI_ERR_IO, "**io",
+					   "**io %s", strerror(errno));
+	return;
     }
     else *error_code = MPI_SUCCESS;
-#endif
 }
