@@ -1,12 +1,13 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_hints.c,v 1.13 2003/04/23 00:16:14 rross Exp $    
+ *   $Id: ad_hints.c,v 1.19 2004/10/04 15:51:24 robl Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
  */
 
 #include "adio.h"
+#include "adio_extern.h"
 
 void ADIOI_GEN_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code)
 {
@@ -18,7 +19,8 @@ void ADIOI_GEN_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code)
 
     MPI_Info info;
     char *value;
-    int flag, intval, tmp_val, nprocs;
+    int flag, intval, tmp_val, nprocs, nprocs_is_valid = 0;
+    static char myname[] = "ADIOI_GEN_SETINFO";
 
     if (fd->info == MPI_INFO_NULL) MPI_Info_create(&(fd->info));
     info = fd->info;
@@ -52,6 +54,7 @@ void ADIOI_GEN_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code)
 
 	/* number of processes that perform I/O in collective I/O */
 	MPI_Comm_size(fd->comm, &nprocs);
+	nprocs_is_valid = 1;
 	sprintf(value, "%d", nprocs);
 	MPI_Info_set(info, "cb_nodes", value);
 	fd->hints->cb_nodes = nprocs;
@@ -59,6 +62,8 @@ void ADIOI_GEN_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code)
 	/* hint indicating that no indep. I/O will be performed on this file */
 	MPI_Info_set(info, "romio_no_indep_rw", "false");
 	fd->hints->no_indep_rw = 0;
+	 /* deferred_open derrived from no_indep_rw and cb_{read,write} */
+	fd->hints->deferred_open = 0;
 
 	/* buffer size for data sieving in independent reads */
 	MPI_Info_set(info, "ind_rd_buffer_size", ADIOI_IND_RD_BUFFER_SIZE_DFLT);
@@ -85,15 +90,20 @@ void ADIOI_GEN_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code)
 		     value, &flag);
 	if (flag && ((intval=atoi(value)) > 0)) {
 	    tmp_val = intval;
+
 	    MPI_Bcast(&tmp_val, 1, MPI_INT, 0, fd->comm);
+	    /* --BEGIN ERROR HANDLING-- */
 	    if (tmp_val != intval) {
-		FPRINTF(stderr, "ADIOI_GEN_SetInfo: the value for key \"cb_buffer_size\" must be the same on all processes\n");
-		MPI_Abort(MPI_COMM_WORLD, 1);
-	    }
-	    else {
-		MPI_Info_set(info, "cb_buffer_size", value);
-		fd->hints->cb_buffer_size = intval;
+		MPIO_ERR_CREATE_CODE_INFO_NOT_SAME(myname,
+						   "cb_buffer_size",
+						   error_code);
+		return;
 	    }
+	    /* --END ERROR HANDLING-- */
+
+	    MPI_Info_set(info, "cb_buffer_size", value);
+	    fd->hints->cb_buffer_size = intval;
+
 	}
 
 	/* new hints for enabling/disabling coll. buffering on
@@ -106,8 +116,11 @@ void ADIOI_GEN_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code)
 		fd->hints->cb_read = ADIOI_HINT_ENABLE;
 	    }
 	    else if (!strcmp(value, "disable") || !strcmp(value, "DISABLE")) {
+		    /* romio_cb_read overrides no_indep_rw */
 		MPI_Info_set(info, "romio_cb_read", value);
+		MPI_Info_set(info, "romio_no_indep_rw", "false");
 		fd->hints->cb_read = ADIOI_HINT_DISABLE;
+		fd->hints->no_indep_rw = ADIOI_HINT_DISABLE;
 	    }
 	    else if (!strcmp(value, "automatic") || !strcmp(value, "AUTOMATIC"))
 	    {
@@ -116,34 +129,50 @@ void ADIOI_GEN_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code)
 	    }
 
 	    tmp_val = fd->hints->cb_read;
+
 	    MPI_Bcast(&tmp_val, 1, MPI_INT, 0, fd->comm);
+	    /* --BEGIN ERROR HANDLING-- */
 	    if (tmp_val != fd->hints->cb_read) {
-		FPRINTF(stderr, "ADIOI_GEN_SetInfo: the value for key \"romio_cb_read\" must be the same on all processes\n");
-		MPI_Abort(MPI_COMM_WORLD, 1);
+		MPIO_ERR_CREATE_CODE_INFO_NOT_SAME(myname,
+						   "romio_cb_read",
+						   error_code);
+		return;
 	    }
+	    /* --END ERROR HANDLING-- */
 	}
-	MPI_Info_get(users_info, "romio_cb_write", MPI_MAX_INFO_VAL, value, &flag);
+	MPI_Info_get(users_info, "romio_cb_write", MPI_MAX_INFO_VAL, value,
+		     &flag);
 	if (flag) {
 	    if (!strcmp(value, "enable") || !strcmp(value, "ENABLE")) {
 		MPI_Info_set(info, "romio_cb_write", value);
 		fd->hints->cb_write = ADIOI_HINT_ENABLE;
 	    }
-	    else if (!strcmp(value, "disable") || !strcmp(value, "DISABLE")) {
+	    else if (!strcmp(value, "disable") || !strcmp(value, "DISABLE"))
+	    {
+		/* romio_cb_write overrides no_indep_rw, too */
 		MPI_Info_set(info, "romio_cb_write", value);
+		MPI_Info_set(info, "romio_no_indep_rw", "false");
 		fd->hints->cb_write = ADIOI_HINT_DISABLE;
+		fd->hints->no_indep_rw = ADIOI_HINT_DISABLE;
 	    }
-	    else if (!strcmp(value, "automatic") || !strcmp(value, "AUTOMATIC"))
+	    else if (!strcmp(value, "automatic") ||
+		     !strcmp(value, "AUTOMATIC"))
 	    {
 		MPI_Info_set(info, "romio_cb_write", value);
 		fd->hints->cb_write = ADIOI_HINT_AUTO;
 	    }
 	
 	    tmp_val = fd->hints->cb_write;
+
 	    MPI_Bcast(&tmp_val, 1, MPI_INT, 0, fd->comm);
+	    /* --BEGIN ERROR HANDLING-- */
 	    if (tmp_val != fd->hints->cb_write) {
-		FPRINTF(stderr, "ADIOI_GEN_SetInfo: the value for key \"romio_cb_write\" must be the same on all processes\n");
-		MPI_Abort(MPI_COMM_WORLD, 1);
+		MPIO_ERR_CREATE_CODE_INFO_NOT_SAME(myname,
+						   "romio_cb_write",
+						   error_code);
+		return;
 	    }
+	    /* --END ERROR HANDLING-- */
 	}
 
 	/* new hint for specifying no indep. read/write will be performed */
@@ -151,8 +180,15 @@ void ADIOI_GEN_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code)
 		     &flag);
 	if (flag) {
 	    if (!strcmp(value, "true") || !strcmp(value, "TRUE")) {
+		    /* if 'no_indep_rw' set, also hint that we will do
+		     * collective buffering: if we aren't doing independent io,
+		     * then we have to do collective  */
 		MPI_Info_set(info, "romio_no_indep_rw", value);
+		MPI_Info_set(info, "romio_cb_write", "enable");
+		MPI_Info_set(info, "romio_cb_read", "enable");
 		fd->hints->no_indep_rw = 1;
+		fd->hints->cb_read = 1;
+		fd->hints->cb_write = 1;
 		tmp_val = 1;
 	    }
 	    else if (!strcmp(value, "false") || !strcmp(value, "FALSE")) {
@@ -164,11 +200,16 @@ void ADIOI_GEN_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code)
 		/* default is above */
 		tmp_val = 0;
 	    }
+
 	    MPI_Bcast(&tmp_val, 1, MPI_INT, 0, fd->comm);
+	    /* --BEGIN ERROR HANDLING-- */
 	    if (tmp_val != fd->hints->no_indep_rw) {
-		FPRINTF(stderr, "ADIOI_GEN_SetInfo: the value for key \"romio_no_indep_rw\" must be the same on all processes\n");
-		MPI_Abort(MPI_COMM_WORLD, 1);
+		MPIO_ERR_CREATE_CODE_INFO_NOT_SAME(myname,
+						   "romio_no_indep_rw",
+						   error_code);
+		return;
 	    }
+	    /* --END ERROR HANDLING-- */
 	}
 	/* new hints for enabling/disabling data sieving on
 	 * reads/writes
@@ -214,16 +255,27 @@ void ADIOI_GEN_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code)
 		     value, &flag);
 	if (flag && ((intval=atoi(value)) > 0)) {
 	    tmp_val = intval;
+
 	    MPI_Bcast(&tmp_val, 1, MPI_INT, 0, fd->comm);
+	    /* --BEGIN ERROR HANDLING-- */
 	    if (tmp_val != intval) {
-		FPRINTF(stderr, "ADIOI_GEN_SetInfo: the value for key \"cb_nodes\" must be the same on all processes\n");
-		MPI_Abort(MPI_COMM_WORLD, 1);
+		    MPIO_ERR_CREATE_CODE_INFO_NOT_SAME(myname,
+						       "cb_nodes",
+						       error_code);
+		    return;
 	    }
-	    else {
-		if (intval < nprocs) {
-		    MPI_Info_set(info, "cb_nodes", value);
-		    fd->hints->cb_nodes = intval;
-		}
+	    /* --END ERROR HANDLING-- */
+
+	    if (!nprocs_is_valid) {
+		/* if hints were already initialized, we might not
+		 * have already gotten this?
+		 */
+		MPI_Comm_size(fd->comm, &nprocs);
+		nprocs_is_valid = 1;
+	    }
+	    if (intval < nprocs) {
+		MPI_Info_set(info, "cb_nodes", value);
+		fd->hints->cb_nodes = intval;
 	    }
 	}
 
@@ -275,6 +327,23 @@ void ADIOI_GEN_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code)
 	}
 	strcpy(fd->hints->cb_config_list, ADIOI_CB_CONFIG_LIST_DFLT);
     }
+    /* deferred_open won't be set by callers, but if the user doesn't
+     * explicitly disable collecitve buffering (two-phase) and does hint that
+     * io w/o independent io is going on, we'll set this internal hint as a
+     * convenience */
+    if ( ( (fd->hints->cb_read != ADIOI_HINT_DISABLE) \
+			    && (fd->hints->cb_write != ADIOI_HINT_DISABLE)\
+			    && fd->hints->no_indep_rw ) ) {
+	    fd->hints->deferred_open = 1;
+    } else {
+	    /* setting romio_no_indep_rw enable and romio_cb_{read,write}
+	     * disable at the same time doesn't make sense. honor
+	     * romio_cb_{read,write} and force the no_indep_rw hint to
+	     * 'disable' */
+	    MPI_Info_set(info, "romio_no_indep_rw", "false");
+	    fd->hints->no_indep_rw = 0;
+	    fd->hints->deferred_open = 0;
+    }
 
     if ((fd->file_system == ADIO_PIOFS) || (fd->file_system == ADIO_PVFS)) {
     /* no data sieving for writes in PIOFS and PVFS, because they do not
