@@ -1,6 +1,5 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_set_sh_fp.c,v 1.3 2000/02/09 21:30:06 thakur Exp $    
- *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
  */
@@ -10,12 +9,14 @@
 /* set the shared file pointer to "offset" etypes relative to the current 
    view */
 
+void ADIOI_NFS_Set_shared_fp(ADIO_File fd, ADIO_Offset offset, int *error_code);
+
 void ADIO_Set_shared_fp(ADIO_File fd, ADIO_Offset offset, int *error_code)
 {
     ADIO_Status status;
     MPI_Comm dupcommself;
 
-#ifdef NFS
+#ifdef ROMIO_NFS
     if (fd->file_system == ADIO_NFS) {
 	ADIOI_NFS_Set_shared_fp(fd, offset, error_code);
 	return;
@@ -24,10 +25,14 @@ void ADIO_Set_shared_fp(ADIO_File fd, ADIO_Offset offset, int *error_code)
 
     if (fd->shared_fp_fd == ADIO_FILE_NULL) {
 	MPI_Comm_dup(MPI_COMM_SELF, &dupcommself);
-	fd->shared_fp_fd = ADIO_Open(dupcommself, fd->shared_fp_fname, 
-             fd->file_system, ADIO_CREATE | ADIO_RDWR | ADIO_DELETE_ON_CLOSE, 
-             0, MPI_BYTE, MPI_BYTE, M_ASYNC, MPI_INFO_NULL, 
-             ADIO_PERM_NULL, error_code);
+	fd->shared_fp_fd = ADIO_Open(MPI_COMM_SELF, dupcommself, 
+				     fd->shared_fp_fname, 
+				     fd->file_system,
+				     fd->fns,
+				     ADIO_CREATE | ADIO_RDWR | ADIO_DELETE_ON_CLOSE, 
+				     0, MPI_BYTE, MPI_BYTE, 0, 
+				     MPI_INFO_NULL, 
+				     ADIO_PERM_NULL, error_code);
     }
 
     if (*error_code != MPI_SUCCESS) return;
