@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_write_coll.c,v 1.24 2003/04/18 20:15:07 David Exp $    
+ *   $Id: ad_write_coll.c,v 1.26 2004/12/23 20:03:32 thakur Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -34,7 +34,8 @@ static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
                          int *send_buf_idx, int *curr_to_proc,
                          int *done_to_proc, int *hole, int iter, 
                          MPI_Aint buftype_extent, int *buf_idx, int *error_code);
-static void ADIOI_Fill_send_buffer(ADIO_File fd, void *buf, ADIOI_Flatlist_node                           *flat_buf, char **send_buf, ADIO_Offset 
+static void ADIOI_Fill_send_buffer(ADIO_File fd, void *buf, ADIOI_Flatlist_node
+                           *flat_buf, char **send_buf, ADIO_Offset 
                            *offset_list, int *len_list, int *send_size, 
                            MPI_Request *requests, int *sent_to_proc, 
                            int nprocs, int myrank, 
@@ -69,12 +70,13 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
        whose request lies in this process's file domain. */
 
     int i, filetype_is_contig, nprocs, nprocs_for_coll, myrank;
-    int *len_list, contig_access_count, interleave_count;
-    int buftype_is_contig, *buf_idx;
+    int contig_access_count, interleave_count = 0, buftype_is_contig;
     int *count_my_req_per_proc, count_my_req_procs, count_others_req_procs;
-    ADIO_Offset *offset_list, start_offset, end_offset, *st_offsets, orig_fp;
-    ADIO_Offset *fd_start, *fd_end, fd_size, min_st_offset, *end_offsets;
-    ADIO_Offset off;
+    ADIO_Offset orig_fp, start_offset, end_offset, fd_size, min_st_offset, off;
+    ADIO_Offset *offset_list = NULL, *st_offsets = NULL, *fd_start = NULL,
+	*fd_end = NULL, *end_offsets = NULL;
+    int *buf_idx = NULL, *len_list = NULL;
+
 
 #ifdef PROFILE
 	MPE_Log_event(13, 0, "start computation");
@@ -87,37 +89,40 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
  * is stored in the hints off the ADIO_File structure
  */
     nprocs_for_coll = fd->hints->cb_nodes;
-
-
-/* For this process's request, calculate the list of offsets and
-   lengths in the file and determine the start and end offsets. */
-
-/* Note: end_offset points to the last byte-offset that will be accessed.
-         e.g., if start_offset=0 and 100 bytes to be read, end_offset=99*/
-
     orig_fp = fd->fp_ind;
-    ADIOI_Calc_my_off_len(fd, count, datatype, file_ptr_type, offset,
-			   &offset_list, &len_list, &start_offset,
-			   &end_offset, &contig_access_count); 
 
-/* each process communicates its start and end offsets to other 
-   processes. The result is an array each of start and end offsets stored
-   in order of process rank. */ 
+    /* only check for interleaving if cb_write isn't disabled */
+    if (fd->hints->cb_write != ADIOI_HINT_DISABLE) {
+	/* For this process's request, calculate the list of offsets and
+	   lengths in the file and determine the start and end offsets. */
+
+	/* Note: end_offset points to the last byte-offset that will be accessed.
+	   e.g., if start_offset=0 and 100 bytes to be read, end_offset=99*/
+
+	ADIOI_Calc_my_off_len(fd, count, datatype, file_ptr_type, offset,
+			      &offset_list, &len_list, &start_offset,
+			      &end_offset, &contig_access_count); 
+
+	/* each process communicates its start and end offsets to other 
+	   processes. The result is an array each of start and end offsets stored
+	   in order of process rank. */ 
     
-    st_offsets = (ADIO_Offset *) ADIOI_Malloc(nprocs*sizeof(ADIO_Offset));
-    end_offsets = (ADIO_Offset *) ADIOI_Malloc(nprocs*sizeof(ADIO_Offset));
+	st_offsets = (ADIO_Offset *) ADIOI_Malloc(nprocs*sizeof(ADIO_Offset));
+	end_offsets = (ADIO_Offset *) ADIOI_Malloc(nprocs*sizeof(ADIO_Offset));
 
-    MPI_Allgather(&start_offset, 1, ADIO_OFFSET, st_offsets, 1, ADIO_OFFSET, 
-		  fd->comm);
-    MPI_Allgather(&end_offset, 1, ADIO_OFFSET, end_offsets, 1, ADIO_OFFSET, 
-		  fd->comm);
+	MPI_Allgather(&start_offset, 1, ADIO_OFFSET, st_offsets, 1,
+		      ADIO_OFFSET, fd->comm);
+	MPI_Allgather(&end_offset, 1, ADIO_OFFSET, end_offsets, 1,
+		      ADIO_OFFSET, fd->comm);
 
-/* are the accesses of different processes interleaved? */
-    interleave_count = 0;
-    for (i=1; i<nprocs; i++)
-	if (st_offsets[i] < end_offsets[i-1]) interleave_count++;
-/* This is a rudimentary check for interleaving, but should suffice
-   for the moment. */
+	/* are the accesses of different processes interleaved? */
+	for (i=1; i<nprocs; i++)
+	    if ((st_offsets[i] < end_offsets[i-1]) && 
+                (st_offsets[i] <= end_offsets[i]))
+                interleave_count++;
+	/* This is a rudimentary check for interleaving, but should suffice
+	   for the moment. */
+    }
 
     ADIOI_Datatype_iscontig(datatype, &buftype_is_contig);
 
@@ -125,10 +130,12 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
 	(!interleave_count && (fd->hints->cb_write == ADIOI_HINT_AUTO)))
     {
 	/* use independent accesses */
-	ADIOI_Free(offset_list);
-	ADIOI_Free(len_list);
-	ADIOI_Free(st_offsets);
-	ADIOI_Free(end_offsets);	
+	if (fd->hints->cb_write != ADIOI_HINT_DISABLE) {
+	    ADIOI_Free(offset_list);
+	    ADIOI_Free(len_list);
+	    ADIOI_Free(st_offsets);
+	    ADIOI_Free(end_offsets);
+	}
 
 	fd->fp_ind = orig_fp;
         ADIOI_Datatype_iscontig(fd->filetype, &filetype_is_contig);
@@ -136,14 +143,15 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
         if (buftype_is_contig && filetype_is_contig) {
             if (file_ptr_type == ADIO_EXPLICIT_OFFSET) {
                 off = fd->disp + (fd->etype_size) * offset;
-                ADIO_WriteContig(fd, buf, count, datatype, ADIO_EXPLICIT_OFFSET,
-                       off, status, error_code);
+                ADIO_WriteContig(fd, buf, count, datatype,
+				 ADIO_EXPLICIT_OFFSET,
+				 off, status, error_code);
             }
             else ADIO_WriteContig(fd, buf, count, datatype, ADIO_INDIVIDUAL,
-                       0, status, error_code);
+				  0, status, error_code);
         }
 	else ADIO_WriteStrided(fd, buf, count, datatype, file_ptr_type,
-                          offset, status, error_code);
+			       offset, status, error_code);
 
 	return;
     }
@@ -161,10 +169,10 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
    located in what file domains */
 
     ADIOI_Calc_my_req(fd, offset_list, len_list, contig_access_count,
-			   min_st_offset, fd_start, fd_end, fd_size,
-			   nprocs, &count_my_req_procs, 
-			   &count_my_req_per_proc, &my_req,
-                           &buf_idx); 
+		      min_st_offset, fd_start, fd_end, fd_size,
+		      nprocs, &count_my_req_procs, 
+		      &count_my_req_per_proc, &my_req,
+		      &buf_idx); 
 
 /* based on everyone's my_req, calculate what requests of other
    processes lie in this process's file domain.
@@ -174,10 +182,10 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
    requests of proc. i lie in this process's file domain. */
 
     ADIOI_Calc_others_req(fd, count_my_req_procs, 
-			       count_my_req_per_proc, my_req, 
-			       nprocs, myrank,
-			       &count_others_req_procs, &others_req); 
-
+			  count_my_req_per_proc, my_req, 
+			  nprocs, myrank,
+			  &count_others_req_procs, &others_req); 
+    
     ADIOI_Free(count_my_req_per_proc);
     for (i=0; i < nprocs; i++) {
 	if (my_req[i].count) {
@@ -231,13 +239,18 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
 
 
 
+/* If successful, error_code is set to MPI_SUCCESS.  Otherwise an error
+ * code is created and returned in error_code.
+ */
 static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
-			 datatype, int nprocs, int myrank, ADIOI_Access
-			 *others_req, ADIO_Offset *offset_list,
-			 int *len_list, int contig_access_count, ADIO_Offset
-                         min_st_offset, ADIO_Offset fd_size,
-			 ADIO_Offset *fd_start, ADIO_Offset *fd_end,
-                         int *buf_idx, int *error_code)
+				 datatype, int nprocs, int myrank,
+				 ADIOI_Access
+				 *others_req, ADIO_Offset *offset_list,
+				 int *len_list, int contig_access_count,
+				 ADIO_Offset
+				 min_st_offset, ADIO_Offset fd_size,
+				 ADIO_Offset *fd_start, ADIO_Offset *fd_end,
+				 int *buf_idx, int *error_code)
 {
 /* Send data to appropriate processes and write in sizes of no more
    than coll_bufsize.    
@@ -259,6 +272,7 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
     MPI_Aint buftype_extent;
     int info_flag, coll_bufsize;
     char *value;
+    static char myname[] = "ADIOI_EXCH_AND_WRITE";
 
     *error_code = MPI_SUCCESS;  /* changed below if error */
     /* only I/O errors are currently reported */
@@ -293,7 +307,9 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
 
     ntimes = (int) ((end_loc - st_loc + coll_bufsize)/coll_bufsize);
 
-    if ((st_loc==-1) && (end_loc==-1)) ntimes = 0; /* this process does no I/O. */
+    if ((st_loc==-1) && (end_loc==-1)) {
+	ntimes = 0; /* this process does no writing. */
+    }
 
     MPI_Allreduce(&ntimes, &max_ntimes, 1, MPI_INT, MPI_MAX,
 		  fd->comm); 
@@ -410,14 +426,25 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
 			recv_size[i] += (int)(ADIOI_MIN(off + (ADIO_Offset)size - 
 						  req_off, req_len));
 
-			if (off+size-req_off < req_len) {
+			if (off+size-req_off < req_len)
+			{
 			    partial_recv[i] = (int) (off + size - req_off);
+
+			    /* --BEGIN ERROR HANDLING-- */
 			    if ((j+1 < others_req[i].count) && 
-                                 (others_req[i].offsets[j+1] < 
-                                     off+size)) { 
-				FPRINTF(stderr, "Error: the filetype specifies an overlapping write\n");
-				MPI_Abort(MPI_COMM_WORLD, 1);
+                                 (others_req[i].offsets[j+1] < off+size))
+			    { 
+				*error_code = MPIO_Err_create_code(MPI_SUCCESS,
+								   MPIR_ERR_RECOVERABLE,
+								   myname,
+								   __LINE__,
+								   MPI_ERR_ARG,
+								   "Filetype specifies overlapping write regions (which is illegal according to the MPI-2 specification)", 0);
+				/* allow to continue since additional
+				 * communication might have to occur
+				 */
 			    }
+			    /* --END ERROR HANDLING-- */
 			    break;
 			}
 		    }
@@ -464,7 +491,7 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
 	MPE_Log_event(7, 0, "start communication");
 #endif
     for (m=ntimes; m<max_ntimes; m++) 
-/* nothing to recv, but check for send. */
+	/* nothing to recv, but check for send. */
 	ADIOI_W_Exchange_data(fd, buf, write_buf, flat_buf, offset_list, 
                             len_list, send_size, recv_size, off, size, count, 
                             start_pos, partial_recv, 
@@ -493,22 +520,26 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
 }
 
 
-
+/* Sets error_code to MPI_SUCCESS if successful, or creates an error code
+ * in the case of error.
+ */
 static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
-                         ADIOI_Flatlist_node *flat_buf, ADIO_Offset 
-                         *offset_list, int *len_list, int *send_size, 
-                         int *recv_size, ADIO_Offset off, int size,
-			 int *count, int *start_pos, int *partial_recv,
-			 int *sent_to_proc, int nprocs, 
-			 int myrank, int
-			 buftype_is_contig, int contig_access_count,
-			 ADIO_Offset min_st_offset, ADIO_Offset fd_size,
-			 ADIO_Offset *fd_start, ADIO_Offset *fd_end, 
-			 ADIOI_Access *others_req, 
-			 int *send_buf_idx, int *curr_to_proc,
-			 int *done_to_proc, int *hole, int iter, 
-                         MPI_Aint buftype_extent, int *buf_idx,
-                         int *error_code)
+				  ADIOI_Flatlist_node *flat_buf, ADIO_Offset 
+				  *offset_list, int *len_list, int *send_size, 
+				  int *recv_size, ADIO_Offset off, int size,
+				  int *count, int *start_pos,
+				  int *partial_recv,
+				  int *sent_to_proc, int nprocs, 
+				  int myrank, int
+				  buftype_is_contig, int contig_access_count,
+				  ADIO_Offset min_st_offset,
+				  ADIO_Offset fd_size,
+				  ADIO_Offset *fd_start, ADIO_Offset *fd_end, 
+				  ADIOI_Access *others_req, 
+				  int *send_buf_idx, int *curr_to_proc,
+				  int *done_to_proc, int *hole, int iter, 
+				  MPI_Aint buftype_extent, int *buf_idx,
+				  int *error_code)
 {
     int i, j, k, *tmp_len, nprocs_recv, nprocs_send, err;
     char **send_buf = NULL; 
@@ -517,9 +548,7 @@ static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
     MPI_Status *statuses, status;
     int *srt_len, sum;
     ADIO_Offset *srt_off;
-#if defined(MPICH2) || !defined(PRINT_ERR_MSG)
     static char myname[] = "ADIOI_W_EXCHANGE_DATA";
-#endif
 
 /* exchange recv_size info so that each process knows how much to
    send to whom. */
@@ -590,21 +619,16 @@ static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
     if (nprocs_recv) {
 	if (*hole) {
 	    ADIO_ReadContig(fd, write_buf, size, MPI_BYTE, 
-                         ADIO_EXPLICIT_OFFSET, off, &status, &err);
+			    ADIO_EXPLICIT_OFFSET, off, &status, &err);
+	    /* --BEGIN ERROR HANDLING-- */
 	    if (err != MPI_SUCCESS) {
-#ifdef MPICH2
-		*error_code = MPIR_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE, myname, __LINE__, MPI_ERR_IO, "**ioRMWrdwr", 0);
+		*error_code = MPIO_Err_create_code(err,
+						   MPIR_ERR_RECOVERABLE, myname,
+						   __LINE__, MPI_ERR_IO,
+						   "**ioRMWrdwr", 0);
 		return;
-#elif defined(PRINT_ERR_MSG)
-		FPRINTF(stderr, "ADIOI_GEN_WriteStridedColl: ROMIO tries to optimize this access by doing a read-modify-write, but is unable to read the file. Please give the file read permission and open it with MPI_MODE_RDWR.\n");
-		MPI_Abort(MPI_COMM_WORLD, 1);
-#else /* MPICH-1 */
-		*error_code = MPIR_Err_setmsg(MPI_ERR_IO, MPIR_READ_PERM,
-			      myname, (char *) 0, (char *) 0);
-		ADIOI_Error(fd, *error_code, myname);
-#endif
-                return;  
 	    } 
+	    /* --END ERROR HANDLING-- */
 	}
     }
 
@@ -613,7 +637,7 @@ static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
 
     if (fd->atomicity) {
         /* bug fix from Wei-keng Liao and Kenin Coloma */
-        requests = (MPI_Request *) 	
+        requests = (MPI_Request *)
 	    ADIOI_Malloc((nprocs_send+1)*sizeof(MPI_Request)); 
         send_req = requests;
     }
