@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: adio_extern.h,v 1.6 2000/02/10 21:54:55 thakur Exp $    
+ *   $Id: adio_extern.h,v 1.8 2004/10/04 15:51:27 robl Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -19,6 +20,8 @@ extern ADIOI_Req_node *ADIOI_Req_avail_head, *ADIOI_Req_avail_tail;
 extern ADIOI_Malloc_req *ADIOI_Malloc_req_head, *ADIOI_Malloc_req_tail;
     /* list of malloced areas for requests, which must be freed in ADIO_End */
 
+extern ADIOI_Datarep *ADIOI_Datarep_head;
+
 /* for f2c and c2f conversion */
 extern ADIO_File *ADIOI_Ftable;
 extern int ADIOI_Ftable_ptr, ADIOI_Ftable_max;
@@ -28,7 +31,7 @@ extern int ADIOI_Reqtable_ptr, ADIOI_Reqtable_max;
 extern MPI_Info *MPIR_Infotable;
 extern int MPIR_Infotable_ptr, MPIR_Infotable_max;
 #endif
-#ifdef XFS
+#ifdef ROMIO_XFS
 extern int ADIOI_Direct_read, ADIOI_Direct_write;
 #endif
 
