@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: fsyncf.c,v 1.13 2002/10/24 17:01:19 gropp Exp $    
+ *   $Id: fsyncf.c,v 1.14 2003/07/08 22:25:42 thakur Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -15,12 +15,16 @@
 #if defined(HAVE_WEAK_SYMBOLS)
 #if defined(HAVE_PRAGMA_WEAK)
 #if defined(FORTRANCAPS)
+extern FORTRAN_API void FORT_CALL MPI_FILE_SYNC( MPI_Fint *, MPI_Fint * );
 #pragma weak MPI_FILE_SYNC = PMPI_FILE_SYNC
 #elif defined(FORTRANDOUBLEUNDERSCORE)
+extern FORTRAN_API void FORT_CALL mpi_file_sync__( MPI_Fint *, MPI_Fint * );
 #pragma weak mpi_file_sync__ = pmpi_file_sync__
 #elif !defined(FORTRANUNDERSCORE)
+extern FORTRAN_API void FORT_CALL mpi_file_sync( MPI_Fint *, MPI_Fint * );
 #pragma weak mpi_file_sync = pmpi_file_sync
 #else
+extern FORTRAN_API void FORT_CALL mpi_file_sync_( MPI_Fint *, MPI_Fint * );
 #pragma weak mpi_file_sync_ = pmpi_file_sync_
 #endif
 
@@ -87,9 +91,9 @@
 #endif
 
 /* Prototype to keep compiler happy */
-FORTRAN_API void FORT_CALL mpi_file_sync_(MPI_Fint *fh, int *ierr );
+FORTRAN_API void FORT_CALL mpi_file_sync_(MPI_Fint *fh, MPI_Fint *ierr );
 
-FORTRAN_API void FORT_CALL mpi_file_sync_(MPI_Fint *fh, int *ierr )
+FORTRAN_API void FORT_CALL mpi_file_sync_(MPI_Fint *fh, MPI_Fint *ierr )
 {
     MPI_File fh_c;
     
