@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: get_sizef.c,v 1.13 2002/10/24 17:01:20 gropp Exp $    
+ *   $Id: get_sizef.c,v 1.14 2003/07/08 22:25:43 thakur Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -15,12 +15,16 @@
 #if defined(HAVE_WEAK_SYMBOLS)
 #if defined(HAVE_PRAGMA_WEAK)
 #if defined(FORTRANCAPS)
+extern FORTRAN_API void FORT_CALL MPI_FILE_GET_SIZE( MPI_Fint *, MPI_Offset*, MPI_Fint * );
 #pragma weak MPI_FILE_GET_SIZE = PMPI_FILE_GET_SIZE
 #elif defined(FORTRANDOUBLEUNDERSCORE)
+extern FORTRAN_API void FORT_CALL mpi_file_get_size__( MPI_Fint *, MPI_Offset*, MPI_Fint * );
 #pragma weak mpi_file_get_size__ = pmpi_file_get_size__
 #elif !defined(FORTRANUNDERSCORE)
+extern FORTRAN_API void FORT_CALL mpi_file_get_size( MPI_Fint *, MPI_Offset*, MPI_Fint * );
 #pragma weak mpi_file_get_size = pmpi_file_get_size
 #else
+extern FORTRAN_API void FORT_CALL mpi_file_get_size_( MPI_Fint *, MPI_Offset*, MPI_Fint * );
 #pragma weak mpi_file_get_size_ = pmpi_file_get_size_
 #endif
 
@@ -87,9 +91,9 @@
 #endif
 
 /* Prototype to keep compiler happy */
-FORTRAN_API void FORT_CALL mpi_file_get_size_(MPI_Fint *fh,MPI_Offset *size, int *ierr );
+FORTRAN_API void FORT_CALL mpi_file_get_size_(MPI_Fint *fh, MPI_Offset *size, MPI_Fint *ierr );
 
-FORTRAN_API void FORT_CALL mpi_file_get_size_(MPI_Fint *fh,MPI_Offset *size, int *ierr )
+FORTRAN_API void FORT_CALL mpi_file_get_size_(MPI_Fint *fh, MPI_Offset *size, MPI_Fint *ierr )
 {
     MPI_File fh_c;
     
