@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: read_allbf.c,v 1.13 2002/10/24 17:01:22 gropp Exp $    
+ *   $Id: read_allbf.c,v 1.14 2003/07/08 22:25:46 thakur Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -15,12 +15,16 @@
 #if defined(HAVE_WEAK_SYMBOLS)
 #if defined(HAVE_PRAGMA_WEAK)
 #if defined(FORTRANCAPS)
+extern FORTRAN_API void FORT_CALL MPI_FILE_READ_ALL_BEGIN( MPI_Fint *, void*, MPI_Fint *, MPI_Fint *, MPI_Fint * );
 #pragma weak MPI_FILE_READ_ALL_BEGIN = PMPI_FILE_READ_ALL_BEGIN
 #elif defined(FORTRANDOUBLEUNDERSCORE)
+extern FORTRAN_API void FORT_CALL mpi_file_read_all_begin__( MPI_Fint *, void*, MPI_Fint *, MPI_Fint *, MPI_Fint * );
 #pragma weak mpi_file_read_all_begin__ = pmpi_file_read_all_begin__
 #elif !defined(FORTRANUNDERSCORE)
+extern FORTRAN_API void FORT_CALL mpi_file_read_all_begin( MPI_Fint *, void*, MPI_Fint *, MPI_Fint *, MPI_Fint * );
 #pragma weak mpi_file_read_all_begin = pmpi_file_read_all_begin
 #else
+extern FORTRAN_API void FORT_CALL mpi_file_read_all_begin_( MPI_Fint *, void*, MPI_Fint *, MPI_Fint *, MPI_Fint * );
 #pragma weak mpi_file_read_all_begin_ = pmpi_file_read_all_begin_
 #endif
 
@@ -88,11 +92,11 @@
 
 #if defined(MPIHP) || defined(MPILAM)
 /* Prototype to keep compiler happy */
-void mpi_file_read_all_begin_(MPI_Fint *fh,void *buf,int *count,
-			      MPI_Fint *datatype, int *ierr );
+void mpi_file_read_all_begin_(MPI_Fint *fh,void *buf,MPI_Fint *count,
+			      MPI_Fint *datatype, MPI_Fint *ierr );
 
-void mpi_file_read_all_begin_(MPI_Fint *fh,void *buf,int *count,
-                      MPI_Fint *datatype,int *ierr )
+void mpi_file_read_all_begin_(MPI_Fint *fh,void *buf,MPI_Fint *count,
+                      MPI_Fint *datatype,MPI_Fint *ierr )
 {
     MPI_File fh_c;
     MPI_Datatype datatype_c;
@@ -104,14 +108,14 @@ void mpi_file_read_all_begin_(MPI_Fint *fh,void *buf,int *count,
 }
 #else
 /* Prototype to keep compiler happy */
-FORTRAN_API void FORT_CALL mpi_file_read_all_begin_(MPI_Fint *fh,void *buf,int *count,
-			      MPI_Datatype *datatype, int *ierr );
+FORTRAN_API void FORT_CALL mpi_file_read_all_begin_(MPI_Fint *fh,void *buf,MPI_Fint *count,
+			      MPI_Fint *datatype, MPI_Fint *ierr );
 
-FORTRAN_API void FORT_CALL mpi_file_read_all_begin_(MPI_Fint *fh,void *buf,int *count,
-                      MPI_Datatype *datatype, int *ierr ){
+FORTRAN_API void FORT_CALL mpi_file_read_all_begin_(MPI_Fint *fh,void *buf,MPI_Fint *count,
+                      MPI_Fint *datatype, MPI_Fint *ierr ){
     MPI_File fh_c;
     
     fh_c = MPI_File_f2c(*fh);
-    *ierr = MPI_File_read_all_begin(fh_c,buf,*count,*datatype);
+    *ierr = MPI_File_read_all_begin(fh_c,buf,*count,(MPI_Datatype) *datatype);
 }
 #endif
