@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: read_ordef.c,v 1.12 2002/10/24 17:01:23 gropp Exp $    
+ *   $Id: read_ordef.c,v 1.13 2003/07/08 22:25:47 thakur Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -15,12 +15,16 @@
 #if defined(HAVE_WEAK_SYMBOLS)
 #if defined(HAVE_PRAGMA_WEAK)
 #if defined(FORTRANCAPS)
+extern FORTRAN_API void FORT_CALL MPI_FILE_READ_ORDERED_END( MPI_Fint *, void*, MPI_Status*, MPI_Fint * );
 #pragma weak MPI_FILE_READ_ORDERED_END = PMPI_FILE_READ_ORDERED_END
 #elif defined(FORTRANDOUBLEUNDERSCORE)
+extern FORTRAN_API void FORT_CALL mpi_file_read_ordered_end__( MPI_Fint *, void*, MPI_Status*, MPI_Fint * );
 #pragma weak mpi_file_read_ordered_end__ = pmpi_file_read_ordered_end__
 #elif !defined(FORTRANUNDERSCORE)
+extern FORTRAN_API void FORT_CALL mpi_file_read_ordered_end( MPI_Fint *, void*, MPI_Status*, MPI_Fint * );
 #pragma weak mpi_file_read_ordered_end = pmpi_file_read_ordered_end
 #else
+extern FORTRAN_API void FORT_CALL mpi_file_read_ordered_end_( MPI_Fint *, void*, MPI_Status*, MPI_Fint * );
 #pragma weak mpi_file_read_ordered_end_ = pmpi_file_read_ordered_end_
 #endif
 
@@ -88,9 +92,9 @@
 
 /* Prototype to keep compiler happy */
 FORTRAN_API void FORT_CALL mpi_file_read_ordered_end_(MPI_Fint *fh,void *buf,MPI_Status *status, 
-				int *ierr );
+				MPI_Fint *ierr );
 
-FORTRAN_API void FORT_CALL mpi_file_read_ordered_end_(MPI_Fint *fh,void *buf,MPI_Status *status, int *ierr )
+FORTRAN_API void FORT_CALL mpi_file_read_ordered_end_(MPI_Fint *fh,void *buf,MPI_Status *status, MPI_Fint *ierr )
 {
     MPI_File fh_c;
     
