@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: read_shf.c,v 1.12 2002/10/24 17:01:24 gropp Exp $    
+ *   $Id: read_shf.c,v 1.13 2003/07/08 22:25:47 thakur Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -15,12 +15,16 @@
 #if defined(HAVE_WEAK_SYMBOLS)
 #if defined(HAVE_PRAGMA_WEAK)
 #if defined(FORTRANCAPS)
+extern FORTRAN_API void FORT_CALL MPI_FILE_READ_SHARED( MPI_Fint *, void*, MPI_Fint *, MPI_Fint *, MPI_Status*, MPI_Fint * );
 #pragma weak MPI_FILE_READ_SHARED = PMPI_FILE_READ_SHARED
 #elif defined(FORTRANDOUBLEUNDERSCORE)
+extern FORTRAN_API void FORT_CALL mpi_file_read_shared__( MPI_Fint *, void*, MPI_Fint *, MPI_Fint *, MPI_Status*, MPI_Fint * );
 #pragma weak mpi_file_read_shared__ = pmpi_file_read_shared__
 #elif !defined(FORTRANUNDERSCORE)
+extern FORTRAN_API void FORT_CALL mpi_file_read_shared( MPI_Fint *, void*, MPI_Fint *, MPI_Fint *, MPI_Status*, MPI_Fint * );
 #pragma weak mpi_file_read_shared = pmpi_file_read_shared
 #else
+extern FORTRAN_API void FORT_CALL mpi_file_read_shared_( MPI_Fint *, void*, MPI_Fint *, MPI_Fint *, MPI_Status*, MPI_Fint * );
 #pragma weak mpi_file_read_shared_ = pmpi_file_read_shared_
 #endif
 
@@ -88,10 +92,10 @@
 
 #if defined(MPIHP) || defined(MPILAM)
 /* Prototype to keep compiler happy */
-void mpi_file_read_shared_(MPI_Fint *fh,void *buf,int *count,
-			   MPI_Fint *datatype,MPI_Status *status, int *ierr );
-void mpi_file_read_shared_(MPI_Fint *fh,void *buf,int *count,
-                  MPI_Fint *datatype,MPI_Status *status, int *ierr )
+void mpi_file_read_shared_(MPI_Fint *fh,void *buf,MPI_Fint *count,
+			   MPI_Fint *datatype,MPI_Status *status, MPI_Fint *ierr );
+void mpi_file_read_shared_(MPI_Fint *fh,void *buf,MPI_Fint *count,
+                  MPI_Fint *datatype,MPI_Status *status, MPI_Fint *ierr )
 {
     MPI_File fh_c;
     MPI_Datatype datatype_c;
@@ -103,14 +107,14 @@ void mpi_file_read_shared_(MPI_Fint *fh,void *buf,int *count,
 }
 #else
 /* Prototype to keep compiler happy */
-FORTRAN_API void FORT_CALL mpi_file_read_shared_(MPI_Fint *fh,void *buf,int *count,
-			   MPI_Datatype *datatype,MPI_Status *status, int *ierr ); 
-FORTRAN_API void FORT_CALL mpi_file_read_shared_(MPI_Fint *fh,void *buf,int *count,
-                  MPI_Datatype *datatype,MPI_Status *status, int *ierr )
+FORTRAN_API void FORT_CALL mpi_file_read_shared_(MPI_Fint *fh,void *buf,MPI_Fint *count,
+			   MPI_Fint *datatype,MPI_Status *status, MPI_Fint *ierr ); 
+FORTRAN_API void FORT_CALL mpi_file_read_shared_(MPI_Fint *fh,void *buf,MPI_Fint *count,
+                  MPI_Fint *datatype,MPI_Status *status, MPI_Fint *ierr )
 {
     MPI_File fh_c;
     
     fh_c = MPI_File_f2c(*fh);
-    *ierr = MPI_File_read_shared(fh_c,buf,*count,*datatype,status);
+    *ierr = MPI_File_read_shared(fh_c,buf,*count,(MPI_Datatype)*datatype,status);
 }
 #endif
