@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ioreq_c2f.c,v 1.7 2002/10/24 15:54:40 gropp Exp $    
+ *   $Id: ioreq_c2f.c,v 1.11 2005/02/18 00:39:06 robl Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -35,6 +35,13 @@ Input Parameters:
 Return Value:
   Fortran I/O-request handle (integer)
 @*/
+#ifdef HAVE_MPI_GREQUEST
+MPI_Fint MPIO_Request_c2f(MPIO_Request request)
+{
+    return ((MPI_Fint)request);
+}
+#else
+
 MPI_Fint MPIO_Request_c2f(MPIO_Request request)
 {
 #ifndef INT_LT_POINTER
@@ -42,8 +49,13 @@ MPI_Fint MPIO_Request_c2f(MPIO_Request request)
 #else
     int i;
 
+    MPID_CS_ENTER();
+
     if ((request <= (MPIO_Request) 0) || (request->cookie != ADIOI_REQ_COOKIE))
-	return (MPI_Fint) 0;
+    {
+	    MPID_CS_EXIT(); 
+	    return (MPI_Fint) 0;
+    }
     if (!ADIOI_Reqtable) {
 	ADIOI_Reqtable_max = 1024;
 	ADIOI_Reqtable = (MPIO_Request *)
@@ -61,6 +73,9 @@ MPI_Fint MPIO_Request_c2f(MPIO_Request request)
     }
     ADIOI_Reqtable_ptr++;
     ADIOI_Reqtable[ADIOI_Reqtable_ptr] = request;
+
+    MPID_CS_EXIT();
     return (MPI_Fint) ADIOI_Reqtable_ptr;
 #endif
 }
+#endif
