@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ioreq_f2c.c,v 1.8 2002/10/24 15:54:40 gropp Exp $    
+ *   $Id: ioreq_f2c.c,v 1.13 2005/02/18 00:39:06 robl Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -35,17 +35,39 @@ Input Parameters:
 Return Value:
   C I/O-request handle (handle)
 @*/
+#ifdef HAVE_MPI_GREQUEST
+MPIO_Request MPIO_Request_f2c(MPI_Fint request) {
+    return((MPIO_Request) request);
+}
+#else
 MPIO_Request MPIO_Request_f2c(MPI_Fint request)
 {
+    int error_code;
+    static char myname[] = "MPIO_REQUEST_F2C";
 
 #ifndef INT_LT_POINTER
     return (MPIO_Request) request;
 #else
-    if (!request) return MPIO_REQUEST_NULL;
-    if ((request < 0) || (request > ADIOI_Reqtable_ptr)) {
-	FPRINTF(stderr, "MPIO_Request_f2c: Invalid request\n");
-	MPI_Abort(MPI_COMM_WORLD, 1);
+
+    MPID_CS_ENTER();
+    
+    /* --BEGIN ERROR HANDLING-- */
+    if (!request) {
+	    error_code = MPIO_REQUEST_NULL;
+	    goto fn_exit;
     }
+    if ((request < 0) || (request > ADIOI_Reqtable_ptr)) {
+	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					  myname, __LINE__, MPI_ERR_REQUEST,
+					  "**request", 0);
+	error_code = MPIO_Err_return_file(MPI_FILE_NULL, error_code);
+	goto fn_exit;
+    }
+    /* --END ERROR HANDLING-- */
+
+fn_exit:
+    MPID_CS_EXIT();
     return ADIOI_Reqtable[request];
 #endif
 }
+#endif
