@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: iwrite_sh.c,v 1.7 2002/10/24 15:54:41 gropp Exp $    
+ *   $Id: iwrite_sh.c,v 1.20 2005/02/18 00:39:07 robl Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -38,80 +38,79 @@ Output Parameters:
 
 .N fortran
 @*/
-int MPI_File_iwrite_shared(MPI_File fh, void *buf, int count, 
-                       MPI_Datatype datatype, MPIO_Request *request)
+#ifdef HAVE_MPI_GREQUEST
+#include "mpiu_greq.h"
+
+int MPI_File_iwrite_shared(MPI_File mpi_fh, void *buf, int count, 
+			   MPI_Datatype datatype, MPIO_Request *request)
+{
+	int error_code;
+	MPI_Status *status;
+
+        MPID_CS_ENTER();
+        MPIR_Nest_incr();
+
+	status = (MPI_Status *) ADIOI_Malloc(sizeof(MPI_Status));
+
+	/* for now, no threads or anything fancy. 
+	 * just call the blocking version */
+	error_code = MPI_File_write_shared(mpi_fh, buf, count, 
+			datatype, status); 
+	/* ROMIO-1 doesn't do anything with status.MPI_ERROR */
+	status->MPI_ERROR = error_code;
+
+	/* kick off the request */
+	MPI_Grequest_start(MPIU_Greq_query_fn, MPIU_Greq_free_fn, 
+			MPIU_Greq_cancel_fn, status, request);
+
+	/* but we did all the work already */
+	MPI_Grequest_complete(*request);
+
+        MPIR_Nest_decr();
+        MPID_CS_EXIT();
+
+	/* passed the buck to the blocking version...*/
+	return MPI_SUCCESS;
+}
+#else
+int MPI_File_iwrite_shared(MPI_File mpi_fh, void *buf, int count, 
+			   MPI_Datatype datatype, MPIO_Request *request)
 {
     int error_code, bufsize, buftype_is_contig, filetype_is_contig;
-#ifndef PRINT_ERR_MSG
-    static char myname[] = "MPI_FILE_IWRITE_SHARED";
-#endif
+    ADIO_File fh;
     int datatype_size, incr;
     ADIO_Status status;
     ADIO_Offset off, shared_fp;
+    static char myname[] = "MPI_FILE_IWRITE_SHARED";
 
-#ifdef PRINT_ERR_MSG
-    if ((fh <= (MPI_File) 0) || (fh->cookie != ADIOI_FILE_COOKIE)) {
-	FPRINTF(stderr, "MPI_File_iwrite_shared: Invalid file handle\n");
-	MPI_Abort(MPI_COMM_WORLD, 1);
-    }
-#else
-    ADIOI_TEST_FILE_HANDLE(fh, myname);
-#endif
+    MPID_CS_ENTER();
+    MPIR_Nest_incr();
 
-    if (count < 0) {
-#ifdef PRINT_ERR_MSG
-	FPRINTF(stderr, "MPI_File_iwrite_shared: Invalid count argument\n");
-	MPI_Abort(MPI_COMM_WORLD, 1);
-#else
-	error_code = MPIR_Err_setmsg(MPI_ERR_ARG, MPIR_ERR_COUNT_ARG,
-				     myname, (char *) 0, (char *) 0);
-	return ADIOI_Error(fh, error_code, myname);
-#endif
-    }
+    fh = MPIO_File_resolve(mpi_fh);
 
-    if (datatype == MPI_DATATYPE_NULL) {
-#ifdef PRINT_ERR_MSG
-        FPRINTF(stderr, "MPI_File_iwrite_shared: Invalid datatype\n");
-        MPI_Abort(MPI_COMM_WORLD, 1);
-#else
-	error_code = MPIR_Err_setmsg(MPI_ERR_TYPE, MPIR_ERR_TYPE_NULL,
-				     myname, (char *) 0, (char *) 0);
-	return ADIOI_Error(fh, error_code, myname);	    
-#endif
-    }
+    /* --BEGIN ERROR HANDLING-- */
+    MPIO_CHECK_FILE_HANDLE(fh, myname, error_code);
+    MPIO_CHECK_COUNT(fh, count, myname, error_code);
+    MPIO_CHECK_DATATYPE(fh, datatype, myname, error_code);
+    /* --END ERROR HANDLING-- */
 
     MPI_Type_size(datatype, &datatype_size);
 
-    if ((count*datatype_size) % fh->etype_size != 0) {
-#ifdef PRINT_ERR_MSG
-        FPRINTF(stderr, "MPI_File_iwrite_shared: Only an integral number of etypes can be accessed\n");
-        MPI_Abort(MPI_COMM_WORLD, 1);
-#else
-	error_code = MPIR_Err_setmsg(MPI_ERR_IO, MPIR_ERR_ETYPE_FRACTIONAL,
-				     myname, (char *) 0, (char *) 0);
-	return ADIOI_Error(fh, error_code, myname);	    
-#endif
-    }
-
-    if ((fh->file_system == ADIO_PIOFS) || (fh->file_system == ADIO_PVFS)) {
-#ifdef PRINT_ERR_MSG
-	FPRINTF(stderr, "MPI_File_iwrite_shared: Shared file pointer not supported on PIOFS and PVFS\n");
-	MPI_Abort(MPI_COMM_WORLD, 1);
-#else
-	error_code = MPIR_Err_setmsg(MPI_ERR_UNSUPPORTED_OPERATION, 
-                    MPIR_ERR_NO_SHARED_FP, myname, (char *) 0, (char *) 0);
-	return ADIOI_Error(fh, error_code, myname);
-#endif
-    }
+    /* --BEGIN ERROR HANDLING-- */
+    MPIO_CHECK_INTEGRAL_ETYPE(fh, count, datatype_size, myname, error_code);
+    MPIO_CHECK_FS_SUPPORTS_SHARED(fh, myname, error_code);
+    /* --END ERROR HANDLING-- */
 
     ADIOI_Datatype_iscontig(datatype, &buftype_is_contig);
     ADIOI_Datatype_iscontig(fh->filetype, &filetype_is_contig);
 
+    ADIOI_TEST_DEFERRED(fh, myname, &error_code);
+
     incr = (count*datatype_size)/fh->etype_size;
     ADIO_Get_shared_fp(fh, incr, &shared_fp, &error_code);
     if (error_code != MPI_SUCCESS) {
-	FPRINTF(stderr, "MPI_File_iwrite_shared: Error! Could not access shared file pointer.\n");
-	MPI_Abort(MPI_COMM_WORLD, 1);
+	/* note: ADIO_Get_shared_fp should have set up error code already? */
+	MPIO_Err_return_file(fh, error_code);
     }
 
     /* contiguous or strided? */
@@ -136,8 +135,8 @@ int MPI_File_iwrite_shared(MPI_File fh, void *buf, int count,
             if (fh->file_system != ADIO_NFS)
                 ADIOI_WRITE_LOCK(fh, off, SEEK_SET, bufsize);
 
-            ADIO_WriteContig(fh, buf, count, datatype, ADIO_EXPLICIT_OFFSET, off, 
-                    &status, &error_code);  
+            ADIO_WriteContig(fh, buf, count, datatype, ADIO_EXPLICIT_OFFSET,
+			     off, &status, &error_code);  
 
             if (fh->file_system != ADIO_NFS)
                 ADIOI_UNLOCK(fh, off, SEEK_SET, bufsize);
@@ -149,7 +148,12 @@ int MPI_File_iwrite_shared(MPI_File fh, void *buf, int count,
     }
     else
 	ADIO_IwriteStrided(fh, buf, count, datatype, ADIO_EXPLICIT_OFFSET,
-		 	    shared_fp, request, &error_code); 
+			   shared_fp, request, &error_code); 
+
+fn_exit:
+    MPIR_Nest_decr();
+    MPID_CS_EXIT();
 
     return error_code;
 }
+#endif
