@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: open.c,v 1.34 2004/05/19 23:55:09 thakur Exp $    
+ *   $Id: open.c,v 1.39 2005/05/23 23:28:11 rross Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -44,12 +44,10 @@ int MPI_File_open(MPI_Comm comm, char *filename, int amode,
                   MPI_Info info, MPI_File *fh)
 {
     int error_code, file_system, flag, /* tmp_amode, */rank;
-#if defined(MPICH2) || !defined(PRINT_ERR_MSG)
-    static char myname[] = "MPI_FILE_OPEN";
-#endif
     char *tmp;
     MPI_Comm dupcomm;
     ADIOI_Fns *fsops;
+    static char myname[] = "MPI_FILE_OPEN";
 
 #ifdef MPI_hpux
     int fl_xmpi;
@@ -57,20 +55,17 @@ int MPI_File_open(MPI_Comm comm, char *filename, int amode,
     HPMP_IO_OPEN_START(fl_xmpi, comm);
 #endif /* MPI_hpux */
 
+    MPID_CS_ENTER();
+    MPIR_Nest_incr();
+
     /* --BEGIN ERROR HANDLING-- */
     if (comm == MPI_COMM_NULL)
     {
-#ifdef MPICH2
-	error_code = MPIR_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE, myname, __LINE__, MPI_ERR_COMM, "**comm", 0);
-	return MPIR_Err_return_file(MPI_FILE_NULL, myname, error_code);
-#elif defined(PRINT_ERR_MSG)
-	FPRINTF(stderr, "MPI_File_open: Invalid communicator\n");
-	MPI_Abort(MPI_COMM_WORLD, 1);
-#else /* MPICH-1 */
-	error_code = MPIR_Err_setmsg(MPI_ERR_COMM, MPIR_ERR_COMM_NULL,
-				     myname, (char *) 0, (char *) 0);
-	return ADIOI_Error(MPI_FILE_NULL, error_code, myname);
-#endif
+	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					  myname, __LINE__, MPI_ERR_COMM,
+					  "**comm", 0);
+	error_code = MPIO_Err_return_comm(comm, error_code);
+	goto fn_exit;
     }
     /* --END ERROR HANDLING-- */
 
@@ -78,68 +73,40 @@ int MPI_File_open(MPI_Comm comm, char *filename, int amode,
     /* --BEGIN ERROR HANDLING-- */
     if (flag)
     {
-#ifdef MPICH2
-	error_code = MPIR_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE, myname, __LINE__, MPI_ERR_COMM, 
-	    "**commnotintra", 0);
-	return MPIR_Err_return_file(MPI_FILE_NULL, myname, error_code);
-#elif defined(PRINT_ERR_MSG)
-	FPRINTF(stderr, "MPI_File_open: Intercommunicator cannot be passed to MPI_File_open\n");
-	MPI_Abort(MPI_COMM_WORLD, 1);
-#else /* MPICH-1 */
-	error_code = MPIR_Err_setmsg(MPI_ERR_COMM, MPIR_ERR_COMM_INTER,
-				     myname, (char *) 0, (char *) 0);
-	return ADIOI_Error(MPI_FILE_NULL, error_code, myname);
-#endif
+	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					  myname, __LINE__, MPI_ERR_COMM, 
+					  "**commnotintra", 0);
+	error_code = MPIO_Err_return_comm(comm, error_code);
+	goto fn_exit;
     }
 
     if ( ((amode&MPI_MODE_RDONLY)?1:0) + ((amode&MPI_MODE_RDWR)?1:0) +
 	 ((amode&MPI_MODE_WRONLY)?1:0) != 1 )
     {
-#ifdef MPICH2
-	     error_code = MPIR_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE, myname, __LINE__, MPI_ERR_AMODE, 
-		 "**fileamodeone", 0);
-	     return MPIR_Err_return_file(MPI_FILE_NULL, myname, error_code);
-#elif defined(PRINT_ERR_MSG)
-	FPRINTF(stderr, "MPI_File_open: Exactly one of MPI_MODE_RDONLY, MPI_MODE_WRONLY, or MPI_MODE_RDWR must be specified\n");
-	MPI_Abort(MPI_COMM_WORLD, 1); 
-#else /* MPICH-1 */
-	error_code = MPIR_Err_setmsg(MPI_ERR_AMODE, 3,
-				     myname, (char *) 0, (char *) 0);
-	return ADIOI_Error(MPI_FILE_NULL, error_code, myname);
-#endif
+	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					  myname, __LINE__, MPI_ERR_AMODE, 
+					  "**fileamodeone", 0);
+	error_code = MPIO_Err_return_comm(comm, error_code);
+	goto fn_exit;
     }
 
     if ((amode & MPI_MODE_RDONLY) && 
             ((amode & MPI_MODE_CREATE) || (amode & MPI_MODE_EXCL)))
     {
-#ifdef MPICH2
-		error_code = MPIR_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE, myname, __LINE__, MPI_ERR_AMODE, 
-		    "**fileamoderead", 0);
-		return MPIR_Err_return_file(MPI_FILE_NULL, myname, error_code);
-#elif defined(PRINT_ERR_MSG)
-	FPRINTF(stderr, "MPI_File_open: It is erroneous to specify MPI_MODE_CREATE or MPI_MODE_EXCL with MPI_MODE_RDONLY\n");
-	MPI_Abort(MPI_COMM_WORLD, 1);
-#else /* MPICH-1 */
-	error_code = MPIR_Err_setmsg(MPI_ERR_AMODE, 5,
-				     myname, (char *) 0, (char *) 0);
-	return ADIOI_Error(MPI_FILE_NULL, error_code, myname);
-#endif
+	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					  myname, __LINE__, MPI_ERR_AMODE, 
+					  "**fileamoderead", 0);
+	error_code = MPIO_Err_return_comm(comm, error_code);
+	goto fn_exit;
     }
 
     if ((amode & MPI_MODE_RDWR) && (amode & MPI_MODE_SEQUENTIAL))
     {
-#ifdef MPICH2
-	error_code = MPIR_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE, myname, __LINE__, MPI_ERR_AMODE, 
-	    "**fileamodeseq", 0);
-	return MPIR_Err_return_file(MPI_FILE_NULL, myname, error_code);
-#elif defined(PRINT_ERR_MSG)
-	FPRINTF(stderr, "MPI_File_open: It is erroneous to specify MPI_MODE_SEQUENTIAL with MPI_MODE_RDWR\n");
-	MPI_Abort(MPI_COMM_WORLD, 1);
-#else /* MPICH-1 */
-	error_code = MPIR_Err_setmsg(MPI_ERR_AMODE, 7,
-				     myname, (char *) 0, (char *) 0);
-	return ADIOI_Error(MPI_FILE_NULL, error_code, myname);
-#endif
+	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					  myname, __LINE__, MPI_ERR_AMODE, 
+					  "**fileamodeseq", 0);
+	error_code = MPIO_Err_return_comm(comm, error_code);
+	goto fn_exit;
     }
     /* --END ERROR HANDLING-- */
 
@@ -157,16 +124,17 @@ int MPI_File_open(MPI_Comm comm, char *filename, int amode,
 */
 
 /* check if ADIO has been initialized. If not, initialize it */
-    if (ADIO_Init_keyval == MPI_KEYVAL_INVALID)
-    {
-
-/* check if MPI itself has been initialized. If not, flag an error.
-   Can't initialize it here, because don't know argc, argv */
+    if (ADIO_Init_keyval == MPI_KEYVAL_INVALID) {
 	MPI_Initialized(&flag);
+
 	/* --BEGIN ERROR HANDLING-- */
 	if (!flag) {
-	    FPRINTF(stderr, "Error: MPI_Init() must be called before using MPI-IO\n");
-	    MPI_Abort(MPI_COMM_WORLD, 1);
+	    error_code = MPIO_Err_create_code(MPI_SUCCESS,
+					      MPIR_ERR_RECOVERABLE,
+					      myname, __LINE__, MPI_ERR_OTHER,
+					      "**initialized", 0);
+	    error_code = MPIO_Err_return_comm(comm, error_code);
+	    goto fn_exit;
 	}
 	/* --END ERROR HANDLING-- */
 
@@ -194,17 +162,11 @@ int MPI_File_open(MPI_Comm comm, char *filename, int amode,
     if (error_code != MPI_SUCCESS)
     {
 	/* ADIO_ResolveFileType() will print as informative a message as it
-	 * possibly can or call MPIR_Err_setmsg.  We just need to propagate 
-	 * the error up.  In the PRINT_ERR_MSG case MPI_Abort has already
-	 * been called as well, so we probably didn't even make it this far.
+	 * possibly can or call MPIO_Err_setmsg.  We just need to propagate 
+	 * the error up.
 	 */
-#ifdef MPICH2
-	return MPIR_Err_return_file(MPI_FILE_NULL, myname, error_code);
-#elif defined(PRINT_ERR_MSG)
-	MPI_Abort(MPI_COMM_WORLD, 1); /* this is mostly here for clarity */
-#else /* MPICH-1 */
-	return ADIOI_Error(MPI_FILE_NULL, error_code, myname);
-#endif
+	error_code = MPIO_Err_return_comm(comm, error_code);
+	goto fn_exit;
     }
 
     /* Test for invalid flags in amode.
@@ -213,47 +175,48 @@ int MPI_File_open(MPI_Comm comm, char *filename, int amode,
      * invalid flags through some functional interface rather than having
      *  these tests here. -- Rob, 06/06/2001
      */
-    if (((file_system == ADIO_PIOFS) || (file_system == ADIO_PVFS) || (file_system == ADIO_PVFS2)) && 
+    if (((file_system == ADIO_PIOFS) ||
+	 (file_system == ADIO_PVFS) ||
+	 (file_system == ADIO_PVFS2) ||
+	 (file_system == ADIO_GRIDFTP)) && 
         (amode & MPI_MODE_SEQUENTIAL))
     {
-#ifdef MPICH2
-	    error_code = MPIR_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE, myname, __LINE__, MPI_ERR_UNSUPPORTED_OPERATION, 
-		"**iosequnsupported", 0);
-	    return MPIR_Err_return_file(MPI_FILE_NULL, myname, error_code);
-#elif defined(PRINT_ERR_MSG)
-	FPRINTF(stderr, "MPI_File_open: MPI_MODE_SEQUENTIAL not supported on PIOFS and PVFS\n");
-	MPI_Abort(MPI_COMM_WORLD, 1);
-#else /* MPICH-1 */
-	error_code = MPIR_Err_setmsg(MPI_ERR_UNSUPPORTED_OPERATION, 
-                    MPIR_ERR_NO_MODE_SEQ, myname, (char *) 0, (char *) 0);
-	return ADIOI_Error(MPI_FILE_NULL, error_code, myname);
-#endif
+	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					  myname, __LINE__,
+					  MPI_ERR_UNSUPPORTED_OPERATION, 
+					  "**iosequnsupported", 0);
+	error_code = MPIO_Err_return_comm(comm, error_code);
+	goto fn_exit;
     }
     /* --END ERROR HANDLING-- */
 
-    /* strip off prefix if there is one */
+    /* strip off prefix if there is one, but only skip prefixes
+     * if they are greater than length one to allow for windows
+     * drive specifications (e.g. c:\...) */
+
     tmp = strchr(filename, ':');
-    /* Only skip prefixes greater than length one to allow for windows drive specification (c:\...)*/
-    /*if (tmp) filename = tmp + 1;*/
-    if (tmp > filename + 1)
+    if (tmp > filename + 1) {
 	filename = tmp + 1;
+    }
 
 /* use default values for disp, etype, filetype */    
-/* set iomode=M_ASYNC. It is used to implement the Intel PFS interface
-   on top of ADIO. Not relevant for MPI-IO implementation */    
 
-    *fh = ADIO_Open(comm, dupcomm, filename, file_system, amode, 0, MPI_BYTE,
-                    MPI_BYTE, M_ASYNC, info, ADIO_PERM_NULL, &error_code);
+    *fh = ADIO_Open(comm, dupcomm, filename, file_system, fsops, amode, 0,
+		    MPI_BYTE, MPI_BYTE, 0, info, ADIO_PERM_NULL, &error_code);
 
-    if (error_code != MPI_SUCCESS)
+    /* --BEGIN ERROR HANDLING-- */
+    if (error_code != MPI_SUCCESS) {
         MPI_Comm_free(&dupcomm);
+    }
+    /* --END ERROR HANDLING-- */
 
     /* determine name of file that will hold the shared file pointer */
     /* can't support shared file pointers on a file system that doesn't
-       support file locking, e.g., PIOFS, PVFS, PVFS2 */
+       support file locking. */
     if ((error_code == MPI_SUCCESS) && ((*fh)->file_system != ADIO_PIOFS)
           && ((*fh)->file_system != ADIO_PVFS) 
-	  && ((*fh)->file_system != ADIO_PVFS2) ){
+	  && ((*fh)->file_system != ADIO_PVFS2)
+	  && ((*fh)->file_system != ADIO_GRIDFTP) ){
 	MPI_Comm_rank(dupcomm, &rank);
 	ADIOI_Shfp_fname(*fh, rank);
 
@@ -270,5 +233,9 @@ int MPI_File_open(MPI_Comm comm, char *filename, int amode,
 #ifdef MPI_hpux
     HPMP_IO_OPEN_END(fl_xmpi, *fh, comm);
 #endif /* MPI_hpux */
+
+fn_exit:
+    MPIR_Nest_decr();
+    MPID_CS_EXIT();
     return error_code;
 }
