@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: write_orde.c,v 1.16 2004/02/12 06:09:19 David Exp $    
+ *   $Id: write_orde.c,v 1.18 2005/02/18 00:39:11 robl Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -36,38 +36,26 @@ Output Parameters:
 
 .N fortran
 @*/
-int MPI_File_write_ordered_end(MPI_File fh, void *buf, MPI_Status *status)
+int MPI_File_write_ordered_end(MPI_File mpi_fh, void *buf, MPI_Status *status)
 {
-#if defined(MPICH2) || !defined(PRINT_ERR_MSG)
     int error_code;
     static char myname[] = "MPI_FILE_WRITE_ORDERED_END";
-#endif
+    ADIO_File fh;
+
+    MPID_CS_ENTER();
+
+    fh = MPIO_File_resolve(mpi_fh);
 
     /* --BEGIN ERROR HANDLING-- */
-#ifdef PRINT_ERR_MSG
-    if ((fh <= (MPI_File) 0) || (fh->cookie != ADIOI_FILE_COOKIE))
-    {
-	FPRINTF(stderr, "MPI_File_write_ordered_end: Invalid file handle\n");
-	MPI_Abort(MPI_COMM_WORLD, 1);
-    }
-#else
-    ADIOI_TEST_FILE_HANDLE(fh, myname);
-#endif
+    MPIO_CHECK_FILE_HANDLE(fh, myname, error_code);
 
     if (!(fh->split_coll_count))
     {
-#ifdef MPICH2
-	error_code = MPIR_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE, myname, __LINE__, MPI_ERR_IO, 
-	    "**iosplitcollnone", 0);
-	return MPIR_Err_return_file(fh, myname, error_code);
-#elif defined(PRINT_ERR_MSG)
-        FPRINTF(stderr, "MPI_File_write_ordered_end: Does not match a previous MPI_File_write_ordered_begin\n");
-        MPI_Abort(MPI_COMM_WORLD, 1);
-#else /* MPICH-1 */
-	error_code = MPIR_Err_setmsg(MPI_ERR_IO, MPIR_ERR_NO_SPLIT_COLL,
-                              myname, (char *) 0, (char *) 0);
-	return ADIOI_Error(fh, error_code, myname);
-#endif
+	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+					  myname, __LINE__, MPI_ERR_IO, 
+					  "**iosplitcollnone", 0);
+	error_code = MPIO_Err_return_file(fh, error_code);
+	goto fn_exit;
     }
     /* --END ERROR HANDLING-- */
 
@@ -77,5 +65,8 @@ int MPI_File_write_ordered_end(MPI_File fh, void *buf, MPI_Status *status)
 #endif
     fh->split_coll_count = 0;
 
+
+fn_exit:
+    MPID_CS_EXIT();
     return MPI_SUCCESS;
 }
