@@ -11,12 +11,23 @@
 
 #define COUNT 1024
 
+void handle_error(int errcode, char *str);
+
+void handle_error(int errcode, char *str) 
+{
+	char msg[MPI_MAX_ERROR_STRING];
+	int resultlen;
+	MPI_Error_string(errcode, msg, &resultlen);
+	fprintf(stderr, "%s: %s\n", str, msg);
+	MPI_Abort(MPI_COMM_WORLD, 1);
+}
+
 /* tests shared file pointer functions */
 
 int main(int argc, char **argv)
 {
     int *buf, i, rank, nprocs, len, sum, global_sum;
-    int errs=0, toterrs;
+    int errs=0, toterrs, errcode;
     char *filename;
     MPI_File fh;
     MPI_Status status;
@@ -33,7 +44,7 @@ int main(int argc, char **argv)
 	    argv++;
 	}
 	if (i >= argc) {
-	    fprintf(stderr, "\n*#  Usage: simple -fname filename\n\n");
+	    fprintf(stderr, "\n*#  Usage: shared_fp -fname filename\n\n");
 	    MPI_Abort(MPI_COMM_WORLD, 1);
 	}
 	argv++;
@@ -56,18 +67,30 @@ int main(int argc, char **argv)
 
     for (i=0; i<COUNT; i++) buf[i] = COUNT*rank + i;
 
-    MPI_File_open(MPI_COMM_WORLD, filename, MPI_MODE_CREATE | MPI_MODE_RDWR,
-		   MPI_INFO_NULL, &fh);
+    errcode = MPI_File_open(MPI_COMM_WORLD, filename, 
+		    MPI_MODE_CREATE | MPI_MODE_RDWR, MPI_INFO_NULL, &fh);
+    if (errcode != MPI_SUCCESS) {
+	    handle_error(errcode, "MPI_File_open");
+    }
 
-    MPI_File_write_shared(fh, buf, COUNT, MPI_INT, &status);
+    errcode = MPI_File_write_shared(fh, buf, COUNT, MPI_INT, &status);
+    if (errcode != MPI_SUCCESS) {
+	    handle_error(errcode, "MPI_File_write_shared");
+    }
 
     for (i=0; i<COUNT; i++) buf[i] = 0;
 
     MPI_Barrier(MPI_COMM_WORLD);
 
-    MPI_File_seek_shared(fh, 0, MPI_SEEK_SET);
+    errcode = MPI_File_seek_shared(fh, 0, MPI_SEEK_SET);
+    if (errcode != MPI_SUCCESS) {
+	    handle_error(errcode, "MPI_File_seek_shared");
+    }
 
-    MPI_File_read_shared(fh, buf, COUNT, MPI_INT, &status);
+    errcode = MPI_File_read_shared(fh, buf, COUNT, MPI_INT, &status);
+    if (errcode != MPI_SUCCESS) {
+	    handle_error(errcode, "MPI_File_read_shared");
+    }
 
     MPI_File_close(&fh);
 
