@@ -1,5 +1,5 @@
 /*
- *  $Id: intra_fns.c,v 1.15 2000/08/23 17:52:30 gropp Exp $
+ *  $Id: intra_fns.c,v 1.21 2002/11/06 00:15:59 thakur Exp $
  *
  *  (C) 1993 by Argonne National Laboratory and Mississipi State University.
  *      See COPYRIGHT in top-level directory.
@@ -107,10 +107,26 @@ static struct _MPIR_COLLOPS intra_collops =  {
 #else
     intra_Bcast,
 #endif
-    intra_Gather, 
-    intra_Gatherv, 
+#ifdef MPID_Gather
+    MPID_FN_Gather,
+#else
+    intra_Gather,
+#endif
+#ifdef MPID_Gatherv
+    MPID_FN_Gatherv,
+#else
+    intra_Gatherv,
+#endif
+#ifdef MPID_Scatter
+    MPID_FN_Scatter,
+#else
     intra_Scatter,
+#endif
+#ifdef MPID_Scatterv
+    MPID_FN_Scatterv,
+#else
     intra_Scatterv,
+#endif
 #ifdef MPID_Allgather
     MPID_FN_Allgather,
 #else
@@ -121,8 +137,16 @@ static struct _MPIR_COLLOPS intra_collops =  {
 #else
     intra_Allgatherv,
 #endif
+#ifdef MPID_Alltoall
+    MPID_FN_Alltoall,
+#else
     intra_Alltoall,
+#endif
+#ifdef MPID_Alltoallv
+    MPID_FN_Alltoallv,
+#else
     intra_Alltoallv,
+#endif
     0, /* Fix me! a dummy for alltoallw */
 #ifdef MPID_Reduce
     MPID_FN_Reduce,
@@ -150,11 +174,15 @@ static struct _MPIR_COLLOPS intra_collops =  {
     intra_Scan,
 #else
     /* This is in intra_scan.c and is now the default */
+#ifdef MPID_Scan
+    MPID_FN_Scan,
+#else
     MPIR_intra_Scan,
+#endif
 #endif
     1                              /* Giving it a refcount of 1 ensures it
-				    * won't ever get freed.
-				    */
+                                    * won't ever get freed.
+                                    *                                     */
 };
 
 MPIR_COLLOPS MPIR_intra_collops = &intra_collops;
@@ -169,7 +197,7 @@ static int intra_Barrier ( struct MPIR_COMMUNICATOR *comm )
   /* Intialize communicator size */
   (void) MPIR_Comm_size ( comm, &size );
 
-#ifdef MPID_Barrier
+#if defined(MPID_Barrier)  &&  !defined(TOPOLOGY_INTRA_FNS_H)
   if (comm->ADIBarrier) {
       MPID_Barrier( comm->ADIctx, comm );
       return MPI_SUCCESS;
@@ -249,6 +277,10 @@ static int intra_Bcast (
   if (root >= size) 
       mpi_errno = MPIR_Err_setmsg( MPI_ERR_ROOT, MPIR_ERR_ROOT_TOOBIG, 
 				   myname, (char *)0, (char *)0, root, size );
+  else if (root < 0) 
+      /* This catches the use of MPI_ROOT in an intracomm broadcast */
+      mpi_errno = MPIR_Err_setmsg( MPI_ERR_ROOT, MPIR_ERR_DEFAULT, myname,
+				   (char *)0, (char *)0, root );
   if (mpi_errno)
       return MPIR_ERROR(comm, mpi_errno, myname );
 #endif
@@ -525,14 +557,15 @@ static int intra_Scatter (
   /* Switch communicators to the hidden collective */
   comm = comm->comm_coll;
 
-  /* Get the size of the send type */
-  MPI_Type_extent ( sendtype->self, &extent );
-
   /* Lock for collective operation */
   MPID_THREAD_LOCK(comm->ADIctx,comm);
 
   /* If I'm the root, send messages to the rest of 'em */
   if ( rank == root ) {
+
+    /* Get the size of the send type */
+    MPI_Type_extent ( sendtype->self, &extent );
+
     for ( i=0; i<root; i++ ) {
 	mpi_errno = MPI_Send( (void *)((char *)sendbuf+i*sendcnt*extent), 
 			     sendcnt, sendtype->self, i, MPIR_SCATTER_TAG, comm->self);
@@ -793,7 +826,7 @@ static int intra_Alltoall(
 	struct MPIR_DATATYPE *recvtype, 
 	struct MPIR_COMMUNICATOR *comm )
 {
-  int          size, i, j;
+  int          size, i, j, rank, dest;
   MPI_Aint     send_extent, recv_extent;
   int          mpi_errno = MPI_SUCCESS;
   MPI_Status  *starray;
@@ -802,6 +835,7 @@ static int intra_Alltoall(
 
   /* Get size and switch to collective communicator */
   MPIR_Comm_size ( comm, &size );
+  MPIR_Comm_rank ( comm, &rank );
   comm = comm->comm_coll;
   
   /* Get extent of send and recv types */
@@ -821,38 +855,39 @@ static int intra_Alltoall(
 	     comm, MPI_ERR_EXHAUSTED, myname );
 
   /* do the communication -- post *all* sends and receives: */
-  /* We could order these, for example, starting with rank+1, so that
-     the FIRST operations involve different nodes, rather than all to
-     node 0.
-   */
   for ( i=0; i<size; i++ ) { 
-      /* We'd like to avoid sending and receiving to ourselves; 
-	 however, this is complicated by the presence of different
-	 sendtype and recvtypes. */
+      /* Performance fix sent in by Duncan Grove <duncan@cs.adelaide.edu.au>.
+         Instead of posting irecvs and isends from rank=0 to size-1, scatter
+         the destinations so that messages don't all go to rank 0 first. 
+         Thanks Duncan! */
+      dest = (rank+i) % size;
+
       if ( (mpi_errno=MPI_Irecv(
-	  (void *)((char *)recvbuf + i*recvcnt*recv_extent),
+	  (void *)((char *)recvbuf + dest*recvcnt*recv_extent),
                            recvcnt,
                            recvtype->self,
-                           i,
+                           dest,
                            MPIR_ALLTOALL_TAG,
                            comm->self,
-                           &reqarray[2*i+1]))
+                           &reqarray[i]))
           )
-          break;
+          return mpi_errno;
+  }
+
+  for ( i=0; i<size; i++ ) { 
+      dest = (rank+i) % size;
       if ((mpi_errno=MPI_Isend(
-	  (void *)((char *)sendbuf+i*sendcount*send_extent),
+	  (void *)((char *)sendbuf + dest*sendcount*send_extent),
                            sendcount,
                            sendtype->self,
-                           i,
+                           dest,
                            MPIR_ALLTOALL_TAG,
                            comm->self,
-                           &reqarray[2*i]))
+                           &reqarray[i+size]))
           )
-          break;
+          return mpi_errno;
   }
   
-  if (mpi_errno) return mpi_errno;
-
   /* ... then wait for *all* of them to finish: */
   mpi_errno = MPI_Waitall(2*size,reqarray,starray);
   if (mpi_errno == MPI_ERR_IN_STATUS) {
@@ -883,7 +918,7 @@ static int intra_Alltoallv (
 	struct MPIR_DATATYPE *recvtype, 
 	struct MPIR_COMMUNICATOR *comm )
 {
-  int        size, i, j, rcnt;
+  int        size, i, j, rcnt, rank, dest;
   MPI_Aint   send_extent, recv_extent;
   int        mpi_errno = MPI_SUCCESS;
   MPI_Status  *starray;
@@ -891,6 +926,7 @@ static int intra_Alltoallv (
   
   /* Get size and switch to collective communicator */
   MPIR_Comm_size ( comm, &size );
+  MPIR_Comm_rank ( comm, &rank );
   comm = comm->comm_coll;
 
   /* Get extent of send and recv types */
@@ -910,30 +946,40 @@ static int intra_Alltoallv (
   /* do the communication -- post *all* sends and receives: */
   rcnt = 0;
   for ( i=0; i<size; i++ ) { 
-      reqarray[2*i] = MPI_REQUEST_NULL;
+      /* Performance fix sent in by Duncan Grove <duncan@cs.adelaide.edu.au>.
+         Instead of posting irecvs and isends from rank=0 to size-1, scatter
+         the destinations so that messages don't all go to rank 0 first. 
+         Thanks Duncan! */
+      dest = (rank+i) % size;
       if (( mpi_errno=MPI_Irecv(
-	                  (void *)((char *)recvbuf+rdispls[i]*recv_extent), 
-                           recvcnts[i], 
+	                  (void *)((char *)recvbuf+rdispls[dest]*recv_extent), 
+                           recvcnts[dest], 
                            recvtype->self,
-                           i,
+                           dest,
                            MPIR_ALLTOALLV_TAG,
                            comm->self,
-                           &reqarray[2*i+1]))
-          )
-          break;
-      rcnt++;
-      if (( mpi_errno=MPI_Isend(
-	                   (void *)((char *)sendbuf+sdispls[i]*send_extent), 
-                           sendcnts[i], 
-                           sendtype->self,
-                           i,
-                           MPIR_ALLTOALLV_TAG,
-                           comm->self,
-                           &reqarray[2*i]))
+                           &reqarray[i]))
           )
           break;
       rcnt++;
   }
+
+  if (!mpi_errno) {
+      for ( i=0; i<size; i++ ) { 
+          dest = (rank+i) % size;
+          if (( mpi_errno=MPI_Isend(
+                     (void *)((char *)sendbuf+sdispls[dest]*send_extent), 
+                     sendcnts[dest], 
+                     sendtype->self,
+                     dest,
+                     MPIR_ALLTOALLV_TAG,
+                     comm->self,
+                     &reqarray[i+size]))
+           )
+              break;
+          rcnt++;
+      }
+  }
   
   /* ... then wait for *all* of them to finish: */
   if (mpi_errno) {
@@ -1000,7 +1046,7 @@ static int intra_Reduce (
   /* If the operation is predefined, we could check that the datatype's
      type signature is compatible with the operation.  
    */
-#ifdef MPID_Reduce
+#if defined(MPID_Reduce)  &&  !defined(TOPOLOGY_INTRA_FNS_H)
   /* Eventually, this could apply the MPID_Reduce routine in a loop for
      counts > 1 */
   if (comm->ADIReduce && count == 1) {
@@ -1164,6 +1210,8 @@ static int intra_Allreduce (
 {
   int mpi_errno, rc;
 
+  if (count == 0) return MPI_SUCCESS;
+
   /* Reduce to 0, then bcast */
   mpi_errno = MPI_Reduce ( sendbuf, recvbuf, count, datatype->self, op, 0, 
 			   comm->self );
