@@ -1,5 +1,5 @@
 /*
- *  $Id: attr_delval.c,v 1.8 1999/08/30 15:42:39 swider Exp $
+ *  $Id: attr_delval.c,v 1.10 2001/11/14 19:54:17 ashton Exp $
  *
  *  (C) 1993 by Argonne National Laboratory and Mississipi State University.
  *      See COPYRIGHT in top-level directory.
@@ -41,7 +41,7 @@ Input Parameters:
 .N MPI_ERR_COMM
 .N MPI_ERR_PERM_KEY
 @*/
-EXPORT_MPI_API int MPI_Attr_delete ( MPI_Comm comm, int keyval )
+int MPI_Attr_delete ( MPI_Comm comm, int keyval )
 {
   MPIR_HBT_node *attr;
   MPIR_Attr_key *attr_key;
@@ -67,15 +67,18 @@ EXPORT_MPI_API int MPI_Attr_delete ( MPI_Comm comm, int keyval )
   MPIR_HBT_lookup(comm_ptr->attr_cache, keyval, &attr);
   if (attr != (MPIR_HBT_node *)0) {
 	if ( attr_key->delete_fn.c_delete_fn ) {
+#ifndef MPID_NO_FORTRAN
 	    if (attr_key->FortranCalling) {
-		MPI_Aint  invall = (MPI_Aint)attr->value;
-		int inval = (int)invall;
-		(*attr_key->delete_fn.f77_delete_fn)(comm, 
+		MPI_Aint invall = (MPI_Aint)attr->value;
+		MPI_Fint inval = (int)invall;
+		MPI_Fint fcomm = MPI_Comm_c2f(comm);
+		(*attr_key->delete_fn.f77_delete_fn)(&fcomm, 
 					   &keyval, &inval,
 					   attr_key->extra_state, &mpi_errno );
 		attr->value = (void *)(MPI_Aint)inval;
 	    }
 	    else
+#endif
 		mpi_errno = (*attr_key->delete_fn.c_delete_fn)(comm, 
 					    keyval, attr->value,
 					    attr_key->extra_state );
