@@ -1,5 +1,5 @@
 /*
- *  $Id: dup_fn.c,v 1.9 1997/02/18 23:06:13 gropp Exp $
+ *  $Id: dup_fn.c,v 1.3 1999/08/20 02:26:35 ashton Exp $
  *
  *  (C) 1993 by Argonne National Laboratory and Mississipi State University.
  *      See COPYRIGHT in top-level directory.
@@ -12,13 +12,13 @@
 MPI_DUP_FN - A function to simple-mindedly copy attributes  
 
 D*/
-int MPIR_dup_fn ( comm, keyval, extra_state, attr_in, attr_out, flag )
-MPI_Comm  comm;
-int       keyval;
-void      *extra_state;
-void      *attr_in;
-void      *attr_out;
-int       *flag;
+int MPIR_dup_fn ( 
+	MPI_Comm comm, 
+	int keyval, 
+	void *extra_state, 
+	void *attr_in, 
+	void *attr_out, 
+	int *flag )
 {
   /* No error checking at present */
 
