@@ -1,5 +1,5 @@
 /*
- *  $Id: keyval_free.c,v 1.7 1999/08/30 15:43:39 swider Exp $
+ *  $Id: keyval_free.c,v 1.9 2002/06/12 22:24:30 ashton Exp $
  *
  *  (C) 1993 by Argonne National Laboratory and Mississipi State University.
  *      See COPYRIGHT in top-level directory.
@@ -47,7 +47,7 @@ Key values are global (they can be used with any and all communicators)
 
 .seealso: MPI_Keyval_create
 @*/
-EXPORT_MPI_API int MPI_Keyval_free ( int *keyval )
+int MPI_Keyval_free ( int *keyval )
 {
   int mpi_errno = MPI_SUCCESS;
   MPIR_Attr_key *attr_key;
@@ -68,6 +68,8 @@ EXPORT_MPI_API int MPI_Keyval_free ( int *keyval )
 
 #ifndef MPIR_NO_ERROR_CHECKING
   MPIR_TEST_MPI_KEYVAL(*keyval,attr_key,MPIR_COMM_WORLD,myname);
+  if (mpi_errno) 
+      return MPIR_ERROR( MPIR_COMM_WORLD, mpi_errno, myname );
   if ( (attr_key->permanent == 1) && (MPIR_Has_been_initialized == 1) ){
       mpi_errno = MPIR_ERRCLASS_TO_CODE(MPI_ERR_ARG,MPIR_ERR_PERM_KEY);
   }
