@@ -1,5 +1,5 @@
 /*
- *  $Id: null_copyfn.c,v 1.3 1999/08/20 02:26:47 ashton Exp $
+ *  $Id: null_copyfn.c,v 1.4 2001/04/20 19:38:31 gropp Exp $
  *
  *  (C) 1993 by Argonne National Laboratory and Mississipi State University.
  *      See COPYRIGHT in top-level directory.
@@ -11,6 +11,9 @@
   
 MPI_NULL_COPY_FN - A function to not copy attributes  
 
+Notes:
+See discussion of 'MPI_Keyval_create' for the use of this function.
+
 D*/
 int MPIR_null_copy_fn ( 
 	MPI_Comm comm, 
