@@ -1,5 +1,5 @@
 /*
- *  $Id: initfutil.c,v 1.18 2004/05/17 13:51:03 gropp Exp $
+ *  $Id: initfutil.c,v 1.19.4.2 2005/05/31 12:47:59 gropp Exp $
  *
  *  (C) 2000 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -31,6 +31,10 @@
 #endif
 #include <stdio.h>
 
+/* Use the PMPI names for routines */
+#define MPI_BUILD_PROFILING
+#include "mpiprof.h"
+
 #define DEBUG(a)
 
 #ifdef F77_NAME_UPPER
@@ -76,6 +80,9 @@ void mpir_init_flog_ ( MPI_Fint *, MPI_Fint * );
 #endif
 
 void mpir_init_fsize_ ( float *, float *, double *, double * );
+#if !defined(SIZEOF_F77_REAL) || !defined(SIZEOF_F77_DOUBLE_PRECISION)
+#error 'SIZEOF_F77_REAL and/or DOUBLE_PRECISION not defined'
+#endif
 #if SIZEOF_F77_REAL == 0 || SIZEOF_F77_DOUBLE_PRECISION == 0 
 void mpir_get_fsize_ (  void );
 #endif
