@@ -1,5 +1,5 @@
 /*
- *  $Id: util_hbt.c,v 1.8 1997/01/07 01:47:07 gropp Exp $
+ *  $Id: util_hbt.c,v 1.5 2000/07/03 21:30:25 gropp Exp $
  *
  *  (C) 1993 by Argonne National Laboratory and Mississipi State University.
  *      See COPYRIGHT in top-level directory.
@@ -12,16 +12,12 @@
 */
 
 #include "mpiimpl.h"
-#ifdef MPI_ADI2
 #include "attr.h"
 #include "sbcnst2.h"
 #define MPIR_SBinit MPID_SBinit
 #define MPIR_SBfree MPID_SBfree
 #define MPIR_SBalloc MPID_SBalloc
 #define MPIR_SBdestroy MPID_SBdestroy
-#else
-#include "mpisys.h"
-#endif
 
 /*===========================================================================*
   Interface for height balanced trees
@@ -96,8 +92,8 @@ void MPIR_HBT_Free()
 MPIR_HBT_new_tree -
 
 +*/
-int MPIR_HBT_new_tree ( tree_out )
-MPIR_HBT *tree_out;
+int MPIR_HBT_new_tree ( 
+	MPIR_HBT *tree_out)
 {
   MPIR_HBT new_tree;
 
@@ -117,10 +113,10 @@ MPIR_HBT *tree_out;
 MPIR_HBT_new_node -
 
 +*/
-int MPIR_HBT_new_node ( keyval, value, node_out )
-MPIR_Attr_key *keyval;
-void *value;
-MPIR_HBT_node **node_out;
+int MPIR_HBT_new_node ( 
+	MPIR_Attr_key *keyval,
+	void *value,
+	MPIR_HBT_node **node_out)
 {
   MPIR_HBT_node *new_node;
 
@@ -142,8 +138,8 @@ MPIR_HBT_node **node_out;
 MPIR_HBT_free_node -
 
 +*/
-int MPIR_HBT_free_node ( node )
-MPIR_HBT_node *node;
+int MPIR_HBT_free_node (
+	MPIR_HBT_node *node)
 {
     TR_PUSH("MPIR_HBT_free_node");
     if (node != (MPIR_HBT_node *)0) {
@@ -159,8 +155,8 @@ MPIR_HBT_node *node;
 MPIR_HBT_free_subtree -
 
 +*/
-int MPIR_HBT_free_subtree ( subtree )
-MPIR_HBT_node *subtree;
+int MPIR_HBT_free_subtree ( 
+	MPIR_HBT_node *subtree)
 {
     TR_PUSH("MPIR_HBT_free_subtree");
 
@@ -178,8 +174,8 @@ MPIR_HBT_node *subtree;
 MPIR_HBT_free_tree -
 
 +*/
-int MPIR_HBT_free_tree ( tree )
-MPIR_HBT tree;
+int MPIR_HBT_free_tree ( 
+	MPIR_HBT tree)
 {
     TR_PUSH("MPIR_HBT_free_tree");
     if ( tree != (MPIR_HBT)0 ) {
@@ -196,10 +192,10 @@ MPIR_HBT tree;
 MPIR_HBT_lookup( -
 
 +*/
-int MPIR_HBT_lookup( tree, keyval, node_out )
-MPIR_HBT      tree;
-int           keyval;
-MPIR_HBT_node **node_out;
+int MPIR_HBT_lookup( 
+	MPIR_HBT      tree,
+	int           keyval,
+	MPIR_HBT_node **node_out)
 {
   int test;
   MPIR_HBT_node *temp = tree->root;
@@ -225,11 +221,11 @@ MPIR_HBT_node **node_out;
 MPIR_HBT_insert( -
 
 +*/
-int MPIR_HBT_insert( tree, node )
-MPIR_HBT      tree;
-MPIR_HBT_node *node;
+int MPIR_HBT_insert( 
+	MPIR_HBT      tree,
+	MPIR_HBT_node *node)
 {
-  MPIR_HBT_node *temp, *inserted, *rebalance_son, *rebalance, *rebalance_father;
+  MPIR_HBT_node *temp, *inserted=0, *rebalance_son, *rebalance, *rebalance_father;
   int done = 0;
   int test, test_rebalance, rebalance_B;
 
@@ -257,18 +253,18 @@ MPIR_HBT_node *node;
     else if (test < 0) {
 	  /* Go left. */
 	  if( (inserted = LEFT(temp)) == (MPIR_HBT_node *)0 ) {
-        /* Found place to insert the new node */
-        inserted = LEFT(temp) = node;
-        done = 1;
+	      /* Found place to insert the new node */
+	      inserted = LEFT(temp) = node;
+	      done = 1;
 	  }
 	  else {
-        /* If not balanced at this point the move the starting location*/
-        /* for rebalancing effort here. */
-        if ( B(inserted) != MPIR_BALANCED ) {
-          rebalance_father = temp;
-          rebalance = inserted;
-        }
-        temp = inserted;
+	      /* If not balanced at this point the move the starting location*/
+	      /* for rebalancing effort here. */
+	      if ( B(inserted) != MPIR_BALANCED ) {
+		  rebalance_father = temp;
+		  rebalance = inserted;
+	      }
+	      temp = inserted;
 	  }
     }
     else if ( test > 0) {
@@ -389,10 +385,10 @@ MPIR_HBT_node *node;
 MPIR_HBT_delete -
 
 +*/
-int MPIR_HBT_delete(tree, keyval, node_out)
-MPIR_HBT      tree;
-int           keyval;
-MPIR_HBT_node **node_out;
+int MPIR_HBT_delete(
+	MPIR_HBT      tree,
+	int           keyval,
+	MPIR_HBT_node **node_out)
 {
   /* The stack keeps elements from root to the node to be deleted.         */
   /* element_stack has pointers to the nodes.  dir_stack has the direction */
